@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 
 from translate.convert import convert
 import os
@@ -7,7 +8,7 @@ from py import test
 
 class TestConvertCommand:
     """Tests running actual commands on files"""
-    convertmodule=convert
+    convertmodule = convert
     defaultoptions = {"progress": "none", "psyco": "none"}
 
     def setup_method(self, method):
@@ -104,8 +105,12 @@ class TestConvertCommand:
         # the convertsummary might be wrapped. this will probably unwrap it
         assert convertsummary in help_string.replace("\n", " ")
         usageline = help_string[:help_string.find("\n")]
-        assert usageline.startswith("usage: ") and "[--version] [-h|--help]" in usageline
-        options = help_string[help_string.find("options:\n"):]
+        # Different versions of optparse might contain either upper or 
+        # lowercase versions of 'Usage:' and 'Options:', so we need to take 
+        # that into account
+        assert (usageline.startswith("Usage: ") or usageline.startswith("usage: ")) \
+            and "[--version] [-h|--help]" in usageline
+        options = help_string[help_string.find("ptions:\n"):]
         options = options[options.find("\n")+1:]
         options = self.help_check(options, "--progress=PROGRESS")
         options = self.help_check(options, "--version")
@@ -113,8 +118,8 @@ class TestConvertCommand:
         options = self.help_check(options, "--manpage")
         options = self.help_check(options, "--errorlevel=ERRORLEVEL")
         options = self.help_check(options, "--psyco=MODE")
-        options = self.help_check(options, "-iINPUT, --input=INPUT")
-        options = self.help_check(options, "-xEXCLUDE, --exclude=EXCLUDE")
-        options = self.help_check(options, "-oOUTPUT, --output=OUTPUT")
+        options = self.help_check(options, "-i INPUT, --input=INPUT")
+        options = self.help_check(options, "-x EXCLUDE, --exclude=EXCLUDE")
+        options = self.help_check(options, "-o OUTPUT, --output=OUTPUT")
         return options
 
