@@ -11,18 +11,18 @@ class TestCSV2PO:
         """helper that converts csv source to po source without requiring files"""
         inputfile = wStringIO.StringIO(csvsource)
         inputcsv = csvl10n.csvfile(inputfile)
-	if template:
-          templatefile = wStringIO.StringIO(template)
-          inputpot = po.pofile(templatefile)
-	else:
-	  inputpot = None
+        if template:
+            templatefile = wStringIO.StringIO(template)
+            inputpot = po.pofile(templatefile)
+        else:
+            inputpot = None
         convertor = csv2po.csv2po(templatepo=inputpot)
-        outputpo = convertor.convertfile(inputcsv)
+        outputpo = convertor.convertstore(inputcsv)
         return outputpo
 
     def singleelement(self, storage):
         """checks that the pofile contains a single non-header element, and returns it"""
-        print storage.getoutput()
+        print str(storage)
         assert len(storage.units) == 1
         return storage.units[0]
 
@@ -36,9 +36,9 @@ class TestCSV2PO:
         # With header
         pofile = self.csv2po(csvheader + csvsource)
         pounit = self.singleelement(pofile)
-        assert pounit.sourcecomments == ["#: " + "intl.charset.default" + "\n"]
-        assert po.unquotefrompo(pounit.msgid) == "ISO-8859-1"
-        assert po.unquotefrompo(pounit.msgstr) == "UTF-16"
+        assert pounit.getlocations() == ['intl.charset.default']
+        assert pounit.source == "ISO-8859-1"
+        assert pounit.target == "UTF-16"
 
     def test_simpleentity_with_template(self):
         """checks that a simple csv entry definition converts properly to a po entry"""
@@ -50,9 +50,9 @@ msgstr ""
 ''' 
         pofile = self.csv2po(csvsource, potsource)
         pounit = self.singleelement(pofile)
-        assert pounit.sourcecomments == ["#: " + "intl.charset.default" + "\n"]
-        assert po.unquotefrompo(pounit.msgid) == "ISO-8859-1"
-        assert po.unquotefrompo(pounit.msgstr) == "UTF-16"
+        assert pounit.getlocations() == ['intl.charset.default']
+        assert pounit.source == "ISO-8859-1"
+        assert pounit.target == "UTF-16"
 
     def test_newlines(self):
         """tests multiline po entries"""
@@ -62,7 +62,7 @@ wat lank aanhou"
 '''
         pofile = self.csv2po(minicsv)
         unit = self.singleelement(pofile)
-        assert unit.sourcecomments == ["#: Random comment\nwith continuation\n"]
+        assert unit.getlocations() == ['Random', 'comment', 'with', 'continuation']
         assert unit.source == "Original text"
         print unit.target
         assert unit.target == "Langdradige teks\nwat lank aanhou"
@@ -85,7 +85,7 @@ wat lank aanhou"
         print str(csvfile)
         pofile = self.csv2po(minicsv)
         unit = pofile.units[0]
-        assert unit.msgid == ['''"Hello \\"Everyone\\""''']
+        assert unit.source == 'Hello "Everyone"'
         assert pofile.findunit('Hello "Everyone"').target == 'Good day "All"'
         print str(pofile)
         for unit in pofile.units:
@@ -113,7 +113,7 @@ msgstr ""
 ''' 
         pofile = self.csv2po(csvsource, potsource)
         pounit = self.singleelement(pofile)
-        assert pounit.msgidcomments[0] == r'"_: KDE comment\n"'
+        assert pounit._extract_msgidcomments() == 'KDE comment'
         assert pounit.source == "Source"
         assert pounit.target == "Target"
 
@@ -124,7 +124,7 @@ class TestCSV2POCommand(test_convert.TestConvertCommand, TestCSV2PO):
     def test_help(self):
         """tests getting help"""
         options = test_convert.TestConvertCommand.test_help(self)
-        options = self.help_check(options, "-tTEMPLATE, --template=TEMPLATE")
+        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "--charset=CHARSET")
         options = self.help_check(options, "--columnorder=COLUMNORDER")
         options = self.help_check(options, "--duplicates=DUPLICATESTYLE", last=True)
