@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 
 from translate.convert import dtd2po
 from translate.convert import test_convert
@@ -13,11 +14,11 @@ class TestDTD2PO:
         inputdtd = dtd.dtdfile(inputfile)
         convertor = dtd2po.dtd2po()
         if not dtdtemplate:
-          outputpo = convertor.convertfile(inputdtd)
+          outputpo = convertor.convertstore(inputdtd)
         else:
           templatefile = wStringIO.StringIO(dtdtemplate)
           templatedtd = dtd.dtdfile(templatefile)
-          outputpo = convertor.mergefiles(templatedtd, inputdtd)
+          outputpo = convertor.mergestore(templatedtd, inputdtd)
         return outputpo
 
     def convertdtd(self, dtdsource):
@@ -32,6 +33,7 @@ class TestDTD2PO:
         """checks that the pofile contains a single non-header element, and returns it"""
         assert len(pofile.units) == 2
         assert pofile.units[0].isheader()
+        print pofile.units[1]
         return pofile.units[1]
 
     def countelements(self, pofile):
@@ -46,15 +48,15 @@ class TestDTD2PO:
         dtdsource = '<!ENTITY test.me "bananas for sale">\n'
         pofile = self.dtd2po(dtdsource)
         pounit = self.singleelement(pofile)
-        assert po.unquotefrompo(pounit.msgid) == "bananas for sale"
-        assert po.unquotefrompo(pounit.msgstr) == ""
+        assert pounit.source == "bananas for sale"
+        assert pounit.target == ""
         # Now with a template language
         dtdtemplate = '<!ENTITY test.me "bananas for sale">\n'
         dtdtranslated = '<!ENTITY test.me "piesangs te koop">\n'
         pofile = self.dtd2po(dtdtranslated, dtdtemplate)
         pounit = self.singleelement(pofile)
-        assert po.unquotefrompo(pounit.msgid) == "bananas for sale"
-        assert po.unquotefrompo(pounit.msgstr) == "piesangs te koop"
+        assert pounit.source == "bananas for sale"
+        assert pounit.target == "piesangs te koop"
 
     def test_convertdtd(self):
         """checks that the convertdtd function is working"""
@@ -62,15 +64,15 @@ class TestDTD2PO:
         posource = self.convertdtd(dtdsource)
         pofile = po.pofile(wStringIO.StringIO(posource))
         unit = self.singleelement(pofile)
-        assert po.unquotefrompo(unit.msgid) == "Save As..."
-        assert po.unquotefrompo(unit.msgstr) == ""
+        assert unit.source == "Save As..."
+        assert unit.target == ""
 
     def test_apos(self):
         """apostrophe should not break a single-quoted entity definition, bug 69"""
         dtdsource = "<!ENTITY test.me 'bananas &apos; for sale'>\n"
         pofile = self.dtd2po(dtdsource)
         pounit = self.singleelement(pofile)
-        assert po.unquotefrompo(pounit.msgid) == "bananas ' for sale"
+        assert pounit.source == "bananas ' for sale"
 
     def test_quotes(self):
         """quotes should be handled in a single-quoted entity definition"""
@@ -78,7 +80,7 @@ class TestDTD2PO:
         pofile = self.dtd2po(dtdsource)
         pounit = self.singleelement(pofile)
         print str(pounit)
-        assert po.unquotefrompo(pounit.msgid) == '"Bananas" for sale'
+        assert pounit.source == '"Bananas" for sale'
 
     def test_emptyentity(self):
         """checks that empty entity definitions survive into po file, bug 15"""
@@ -95,19 +97,34 @@ class TestDTD2PO:
         unit = self.singleelement(pofile)
         print unit
         assert "credit.translation" in str(unit)
-        assert po.unquotefrompo(unit.msgstr) == "Translators Names"
+        # We don't want this to simply be seen as a header:
+        assert len(unit.getid()) != 0
+        assert unit.target == "Translators Names"
 
-    def test_kdecomment_merge(self):
-        """test that LOCALIZATION NOTES are added properly as KDE comments and merged with duplicate comments"""
+    def test_localisaton_note_simple(self):
+        """test the simple localisation more becomes a #. comment"""
+        dtdsource = '''<!-- LOCALIZATION NOTE (alwaysCheckDefault.height):
+  There's some sort of bug which makes wrapping checkboxes not properly reflow,
+  causing the bottom border of the groupbox to be cut off; set this
+  appropriately if your localization causes this checkbox to wrap.
+-->
+<!ENTITY alwaysCheckDefault.height  "3em">
+'''
+        pofile = self.dtd2po(dtdsource)
+        posource = str(pofile)
+        print posource
+        assert posource.count('#.') == 5 # 1 Header extracted from, 3 comment lines, 1 autoinserted comment
+
+    def test_localisation_note_merge(self):
+        """test that LOCALIZATION NOTES are added properly as #. comments and disambiguated with msgctxt entries"""
         dtdtemplate = '<!--LOCALIZATION NOTE (%s): Some note -->\n' + \
             '<!ENTITY %s "Source text">\n'
         dtdsource = dtdtemplate % ("note1.label", "note1.label") + dtdtemplate % ("note2.label", "note2.label")
         pofile = self.dtd2po(dtdsource)
-        pofile.units = pofile.units[1:]
-        posource = str(pofile)
+        posource = str(pofile.units[1]) + str(pofile.units[2])
         print posource
-        assert posource.count('"_:') == 2
-        assert posource.count('\\n') == 2
+        assert posource.count('#.') == 2
+        assert posource.count('msgctxt') == 2
 
     def test_donttranslate_simple(self):
         """check that we handle DONT_TRANSLATE messages properly"""
@@ -158,17 +175,17 @@ class TestDTD2PO:
         pounit = self.singleelement(pofile)
         # We still need to decide how we handle line line breaks in the DTD entities.  It seems that we should actually
         # drop the line break but this has not been implemented yet.
-        assert po.unquotefrompo(pounit.msgid, True) == "First line then \nnext lines."
+        assert pounit.source == "First line then \nnext lines."
         # No space at the end of the line
         dtdsource = '<!ENTITY  noupdatesfound.intro "First line then\n' + \
           '                                          next lines.">\n'
         pofile = self.dtd2po(dtdsource)
-        unit = self.singleelement(pofile)
-        assert po.unquotefrompo(unit.msgid, True) == "First line then \nnext lines."
+        pounit = self.singleelement(pofile)
+        assert pounit.source == "First line then \nnext lines."
 
     def test_accesskeys_folding(self):
-	"""test that we fold accesskeys into message strings"""
-	dtdsource_template = '<!ENTITY  fileSaveAs.%s "Save As...">\n<!ENTITY  fileSaveAs.%s "S">\n'
+        """test that we fold accesskeys into message strings"""
+        dtdsource_template = '<!ENTITY  fileSaveAs.%s "Save As...">\n<!ENTITY  fileSaveAs.%s "S">\n'
         lang_template = '<!ENTITY  fileSaveAs.%s "Gcina ka...">\n<!ENTITY  fileSaveAs.%s "G">\n'
         for label in ("label", "title"):
           for accesskey in ("accesskey", "accessKey", "akey"):
@@ -183,7 +200,7 @@ class TestDTD2PO:
 
     def test_accesskeys_mismatch(self):
         """check that we can handle accesskeys that don't match and thus can't be folded into the .label entry"""
-	dtdsource = '<!ENTITY  fileSave.label "Save">\n' + \
+        dtdsource = '<!ENTITY  fileSave.label "Save">\n' + \
            '<!ENTITY  fileSave.accesskey "z">\n'
         pofile = self.dtd2po(dtdsource)
         assert self.countelements(pofile) == 2
@@ -194,7 +211,29 @@ class TestDTD2PO:
           '                                          next lines.">\n'
         pofile = self.dtd2po(dtdsource)
         unit = self.singleelement(pofile)
-        assert po.unquotefrompo(unit.msgid, True) == "First line then \nnext lines."
+        assert unit.source == "First line then \nnext lines."
+
+    def test_multiline_with_blankline(self):
+        """test that we can process a multiline entity that has a blank line in it, bug 331"""
+        dtdsource = '''
+<!ENTITY multiline.text "
+Some text
+
+Some other text
+">'''
+        pofile = self.dtd2po(dtdsource)
+        unit = self.singleelement(pofile)
+        assert unit.source == "Some text \n \nSome other text"
+
+    def test_mulitline_closing_quotes(self):
+        """test that we support various styles and spaces after closing quotes on multiline entities"""
+        dtdsource = '''
+<!ENTITY pref.plural '<span>opsies</span><span
+                      class="noWin">preferences</span>' >
+'''
+        pofile = self.dtd2po(dtdsource)
+        unit = self.singleelement(pofile)
+        assert unit.source == '<span>opsies</span><span \nclass="noWin">preferences</span>'
 
     def test_preserving_spaces(self):
         """test that we preserve space that appear at the start of the first line of a DTD entity"""
@@ -202,12 +241,13 @@ class TestDTD2PO:
         dtdsource = '<!ENTITY mainWindow.titlemodifiermenuseparator " - ">'
         pofile = self.dtd2po(dtdsource)
         unit = self.singleelement(pofile)
-        assert po.unquotefrompo(unit.msgid) == " - "
+        assert unit.source == " - "
         # Double line and spaces
         dtdsource = '<!ENTITY mainWindow.titlemodifiermenuseparator " - with a newline\n    and more text">'
         pofile = self.dtd2po(dtdsource)
         unit = self.singleelement(pofile)
-        assert po.unquotefrompo(unit.msgid, True) == " - with a newline \nand more text"
+        print repr(unit.source)
+        assert unit.source == " - with a newline \nand more text"
 
     def test_escaping_newline_tabs(self):
         """test that we handle all kinds of newline permutations"""
@@ -218,9 +258,9 @@ class TestDTD2PO:
         thepo = po.pounit()
         converter.convertstrings(thedtd, thepo)
         print thedtd
-        print thepo.msgid
+        print thepo.source
         # \n in a dtd should also appear as \n in the PO file
-        assert po.unquotefrompo(thepo.msgid) == r"A hard coded newline.\nAnd tab\t and a \r carriage return."
+        assert thepo.source == r"A hard coded newline.\nAnd tab\t and a \r carriage return."
 
     def test_abandoned_accelerator(self):
         """test that when a language DTD has an accelerator but the template DTD does not that we abandon the accelerator"""
@@ -228,12 +268,12 @@ class TestDTD2PO:
         dtdlanguage = '<!ENTITY test.label "Toets">\n<!ENTITY test.accesskey "T">\n'
         pofile = self.dtd2po(dtdlanguage, dtdtemplate)
         unit = self.singleelement(pofile)
-        assert po.unquotefrompo(unit.msgid) == "Test"
-        assert po.unquotefrompo(unit.msgstr) == "Toets"
+        assert unit.source == "Test"
+        assert unit.target == "Toets"
 
     def test_unassociable_accelerator(self):
         """test to see that we can handle accelerator keys that cannot be associated correctly"""
-        dtdsource ='<!ENTITY  managecerts.button "Manage Certificates...">\n<!ENTITY  managecerts.accesskey "M">'
+        dtdsource = '<!ENTITY  managecerts.button "Manage Certificates...">\n<!ENTITY  managecerts.accesskey "M">'
         pofile = self.dtd2po(dtdsource)
         assert pofile.units[1].source == "Manage Certificates..."
         assert pofile.units[2].source == "M"
@@ -254,9 +294,9 @@ class TestDTD2PO:
         pofile = self.dtd2po(dtdlanguage, dtdtemplate)
         print pofile
         assert pofile.units[3].source == "Manage Certificates..."
-        assert pofile.units[3].target == "ﺇﺩﺍﺭﺓ ﺎﻠﺸﻫﺍﺩﺎﺗ..."
+        assert pofile.units[3].target == u"ﺇﺩﺍﺭﺓ ﺎﻠﺸﻫﺍﺩﺎﺗ..."
         assert pofile.units[4].source == "M"
-        assert pofile.units[4].target == "ﺩ"
+        assert pofile.units[4].target == u"ﺩ"
 
     def wtest_accelerator_keys_not_in_sentence(self):
         """tests to ensure that we can manage accelerator keys that are not part of the transated sentence eg in Chinese"""
@@ -282,13 +322,13 @@ class TestDTD2PO:
         assert self.countelements(pofile) == 0
 
     def test_linewraps(self):
-        """check that empty line wraps are not placed in po file"""
+        """check that redundant line wraps are removed from the po file"""
         dtdsource = '''<!ENTITY generic.longDesc "
 <p>Test me.</p>
 ">'''
         pofile = self.dtd2po(dtdsource)
         pounit = self.singleelement(pofile)
-        assert po.unquotefrompo(pounit.msgid, True) == "<p>Test me.</p>"
+        assert pounit.source == "<p>Test me.</p>"
 
     def test_merging_with_new_untranslated(self):
         """test that when we merge in new untranslated strings with existing translations we manage the encodings properly"""
@@ -318,5 +358,5 @@ class TestDTD2POCommand(test_convert.TestConvertCommand, TestDTD2PO):
         """tests getting help"""
         options = test_convert.TestConvertCommand.test_help(self)
         options = self.help_check(options, "-P, --pot")
-        options = self.help_check(options, "-tTEMPLATE, --template=TEMPLATE")
+        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "--duplicates=DUPLICATESTYLE", last=True)
