@@ -2,8 +2,6 @@
 
 from translate.convert import moz2po
 from translate.convert import test_convert
-from translate.misc import wStringIO
-from translate.storage import po
 
 class TestMoz2PO:
   pass
@@ -18,4 +16,4 @@ class TestMoz2POCommand(test_convert.TestConvertCommand, TestMoz2PO):
         options = test_convert.TestConvertCommand.test_help(self)
         options = self.help_check(options, "--duplicates=DUPLICATESTYLE")
         options = self.help_check(options, "-P, --pot")
-        options = self.help_check(options, "-tTEMPLATE, --template=TEMPLATE", last=True)
+        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE", last=True)
