@@ -13,20 +13,20 @@ class TestPO2CSV:
         inputfile = wStringIO.StringIO(posource)
         inputpo = po.pofile(inputfile)
         convertor = po2csv.po2csv()
-        outputcsv = convertor.convertfile(inputpo)
+        outputcsv = convertor.convertstore(inputpo)
         return outputcsv
 
     def csv2po(self, csvsource, template=None):
         """helper that converts csv source to po source without requiring files"""
         inputfile = wStringIO.StringIO(csvsource)
         inputcsv = csvl10n.csvfile(inputfile)
-	if template:
-          templatefile = wStringIO.StringIO(template)
-          inputpot = po.pofile(templatefile)
-	else:
-	  inputpot = None
+        if template:
+            templatefile = wStringIO.StringIO(template)
+            inputpot = po.pofile(templatefile)
+        else:
+            inputpot = None
         convertor = csv2po.csv2po(templatepo=inputpot)
-        outputpo = convertor.convertfile(inputcsv)
+        outputpo = convertor.convertstore(inputcsv)
         return outputpo
 
     def singleelement(self, storage):
