@@ -21,7 +21,7 @@ class TestPO2DTD:
         inputfile = wStringIO.StringIO(posource)
         inputpo = po.pofile(inputfile)
         convertor = po2dtd.po2dtd()
-        outputdtd = convertor.convertfile(inputpo)
+        outputdtd = convertor.convertstore(inputpo)
         return outputdtd
 
     def merge2dtd(self, dtdsource, posource):
@@ -31,7 +31,7 @@ class TestPO2DTD:
         templatefile = wStringIO.StringIO(dtdsource)
         templatedtd = dtd.dtdfile(templatefile)
         convertor = po2dtd.redtd(templatedtd)
-        outputdtd = convertor.convertfile(inputpo)
+        outputdtd = convertor.convertstore(inputpo)
         return outputdtd
 
     def convertdtd(self, posource, dtdtemplate):
@@ -130,6 +130,27 @@ class TestPO2DTD:
         dtdsource = str(dtdfile)
         assert "Dimpled Ring" in dtdsource
 
+    def test_entities_two(self):
+        """test the error ouput when we find two entities"""
+        simplestring = '''#: simple.string second.string\nmsgid "Simple String"\nmsgstr "Dimpled Ring"\n'''
+        dtdfile = self.po2dtd(simplestring)
+        dtdsource = str(dtdfile)
+        assert "CONVERSION NOTE - multiple entities" in dtdsource
+
+    def test_entities(self):
+        """tests that entities are correctly idnetified in the dtd"""
+        simplestring = '''#: simple.string\nmsgid "Simple String"\nmsgstr "Dimpled Ring"\n'''
+        dtdfile = self.po2dtd(simplestring)
+        dtdsource = str(dtdfile)
+        assert dtdsource.startswith("<!ENTITY simple.string")
+
+    def test_comments_translator(self):
+        """tests for translator comments"""
+        simplestring = '''# Comment1\n# Comment2\n#: simple.string\nmsgid "Simple String"\nmsgstr "Dimpled Ring"\n'''
+        dtdfile = self.po2dtd(simplestring)
+        dtdsource = str(dtdfile)
+        assert dtdsource.startswith("<!-- Comment1 -->")
+
     def test_retains_hashprefix(self):
         """tests that hash prefixes in the dtd are retained"""
         hashpo = '''#: lang.version\nmsgid "__MOZILLA_LOCALE_VERSION__"\nmsgstr "__MOZILLA_LOCALE_VERSION__"\n'''
@@ -173,7 +194,6 @@ class TestPO2DTD:
         self.check_roundtrip(r'''"Single-Quote Escape \' "''')
         # NOTE: if both quote marks are present, than ' is converted to &apos;
         self.check_roundtrip(r"""'Both Quotes "" &apos;&apos; '""")
-        assert self.roundtripstring(r"""'Both Quotes "" '' '""") == r"""'Both Quotes "" &apos;&apos; '"""
 
     def test_merging_entries_with_spaces_removed(self):
         """dtd2po removes pretty printed spaces, this tests that we can merge this back into the pretty printed dtd"""
@@ -203,7 +223,7 @@ class TestPO2DTDCommand(test_convert.TestConvertCommand, TestPO2DTD):
     def test_help(self):
         """tests getting help"""
         options = test_convert.TestConvertCommand.test_help(self)
-        options = self.help_check(options, "-tTEMPLATE, --template=TEMPLATE")
+        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "--fuzzy")
         options = self.help_check(options, "--nofuzzy", last=True)
 
