@@ -2,8 +2,6 @@
 
 from translate.convert import po2moz
 from translate.convert import test_convert
-from translate.misc import wStringIO
-from translate.storage import po
 
 class TestPO2Moz:
   pass
@@ -16,8 +14,8 @@ class TestPO2MozCommand(test_convert.TestConvertCommand, TestPO2Moz):
     def test_help(self):
         """tests getting help"""
         options = test_convert.TestConvertCommand.test_help(self)
-        options = self.help_check(options, "-tTEMPLATE, --template=TEMPLATE")
-        options = self.help_check(options, "-lLOCALE, --locale=LOCALE")
+        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
+        options = self.help_check(options, "-l LOCALE, --locale=LOCALE")
         options = self.help_check(options, "--clonexpi=CLONEXPI")
         options = self.help_check(options, "--fuzzy")
         options = self.help_check(options, "--nofuzzy", last=True)
