@@ -5,8 +5,6 @@ from translate.convert import oo2po
 from translate.convert import test_convert
 from translate.misc import wStringIO
 from translate.storage import po
-from translate.storage import oo
-from py import test
 import warnings
 import os
 
@@ -57,12 +55,12 @@ class TestPO2OO:
 
     def test_pofilter(self):
         """Tests integration with pofilter"""
-	#Some bad po with a few errors:
-	posource = '#: sourcefile.bla#ID_NUMBER.txet.gnirts\nmsgid "<tag cow=\\"3\\">Mistake."\nmsgstr "  <etiket koei=\\"3\\">(fout) "'
+        #Some bad po with a few errors:
+        posource = '#: sourcefile.bla#ID_NUMBER.txet.gnirts\nmsgid "<tag cow=\\"3\\">Mistake."\nmsgstr "  <etiket koei=\\"3\\">(fout) "'
         filter = po2oo.filter
-	pofile = po.pofile()
-	pofile.parse(posource)
-	assert not filter.validelement(pofile.units[0], "dummyname.po", "exclude-all")
+        pofile = po.pofile()
+        pofile.parse(posource)
+        assert not filter.validelement(pofile.units[0], "dummyname.po", "exclude-all")
 
     def test_roundtrip_simple(self):
         """checks that simple strings make it through a oo->po->oo roundtrip"""
@@ -90,6 +88,15 @@ class TestPO2OO:
         self.check_roundtrip(r'''"Single-Quote Escape \' "''')
         self.check_roundtrip(r"""'Both Quotes "" '' '""")
 
+    def xtest_roundtrip_spaces(self):
+        # FIXME: this test fails because the resultant PO file returns as po.isempty since .isblank returns true
+        # which is caused by isblankmsgtr returning True.  Its a complete mess which would mean unravelling lots
+        # of yuch in pypo.  Until we have time to do that unravelling we're diabling this test.  You can reenable 
+        # once we've fixed that.
+        """checks that (escaped) quotes in strings make it through a oo->po->oo roundtrip"""
+        self.check_roundtrip(" ")
+        self.check_roundtrip(u"\u00a0")
+
     def test_default_timestamp(self):
         """test to ensure that we revert to the default timestamp"""
         oointro, oooutro = r'svx	source\dialog\numpages.src	0	string	RID_SVXPAGE_NUM_OPTIONS	STR_BULLET			0	en-US	Text				', '\r\n'
@@ -110,6 +117,39 @@ class TestPO2OO:
         assert po2oo.convertoo(inputfile, outputfile, templatefile, targetlanguage="af-ZA")
         assert "\tKolom1\\tKolom2\\r\\n\t" in outputfile.getvalue()
 
+    def test_helpcontent_escapes(self):
+        """test to ensure that we convert helpcontent escapes correctly"""
+        # Note how this test specifically uses incorrect spacing in the 
+        # translation. The extra space before 'hid' and an extra space before
+        # the closing tag should not confuse us.
+        oosource = r'helpcontent2	source\text\shared\3dsettings_toolbar.xhp	0	help	par_idN1056A				0	en-US	\<ahelp hid=\".\"\>The 3D-Settings toolbar controls properties of selected 3D objects.\</ahelp\>				2002-02-02 02:02:02' + '\r\n'
+        posource = r'''#: 3dsettings_toolbar.xhp#par_idN1056A.help.text
+msgid ""
+"<ahelp hid=\".\">The 3D-Settings toolbar controls properties of selected 3D "
+"ob jects.</ahelp>"
+msgstr ""
+"<ahelp  hid=\".\" >Zeee 3DDDD-Settings toolbar controls properties of selected 3D "
+"objects.</ahelp>"
+'''
+        inputfile = wStringIO.StringIO(posource)
+        outputfile = wStringIO.StringIO()
+        templatefile = wStringIO.StringIO(oosource)
+        assert po2oo.convertoo(inputfile, outputfile, templatefile, targetlanguage="af-ZA")
+        assert r"\<ahelp  hid=\".\" \>Zeee 3DDDD-Settings toolbar controls properties of selected 3D objects.\</ahelp\>" in outputfile.getvalue()
+
+    def test_helpcontent_escapes2(self):
+        """test to ensure that we convert helpcontent escapes correctly"""
+        oosource = r'helpcontent2	source\text\scalc\05\empty_cells.xhp	0	help	par_id2629474				0	en-US	A1: <empty>				2002-02-02 02:02:02' + '\r\n'
+        posource = r'''#: empty_cells.xhp#par_id2629474.help.text 
+msgid "A1: <empty>"
+msgstr "Aa1: <empty>"
+'''
+        inputfile = wStringIO.StringIO(posource)
+        outputfile = wStringIO.StringIO()
+        templatefile = wStringIO.StringIO(oosource)
+        assert po2oo.convertoo(inputfile, outputfile, templatefile, targetlanguage="af-ZA")
+        assert r"Aa1: <empty>" in outputfile.getvalue()
+
 class TestPO2OOCommand(test_convert.TestConvertCommand, TestPO2OO):
     """Tests running actual po2oo commands on files"""
     convertmodule = po2oo
@@ -125,12 +165,12 @@ class TestPO2OOCommand(test_convert.TestConvertCommand, TestPO2OO):
         options = self.help_check(options, "--filteraction")
         options = self.help_check(options, "--fuzzy")
         options = self.help_check(options, "--nofuzzy")
-        options = self.help_check(options, "-tTEMPLATE, --template=TEMPLATE")
+        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "--multifile=MULTIFILESTYLE", last=True)
 
     def merge2oo(self, oosource, posource):
         """helper that merges po translations to oo source through files"""
-        outputoo = convertor.convertfile(inputpo)
+        outputoo = convertor.convertstore(inputpo)
         return outputoo
 
     def convertoo(self, posource, ootemplate, language="en-US"):
