@@ -1,10 +1,9 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 
 from translate.convert import po2txt
 from translate.convert import test_convert
 from translate.misc import wStringIO
-from translate.storage import po
-from translate.storage import txt
 
 class TestPO2Txt:
     def po2txt(self, posource, txttemplate=None):
@@ -54,8 +53,8 @@ class TestPO2TxtCommand(test_convert.TestConvertCommand, TestPO2Txt):
     def test_help(self):
         """tests getting help"""
         options = test_convert.TestConvertCommand.test_help(self)
-        options = self.help_check(options, "-tTEMPLATE, --template=TEMPLATE")
+        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "--fuzzy")
         options = self.help_check(options, "--nofuzzy")
         options = self.help_check(options, "--encoding")
-        options = self.help_check(options, "-wWRAP, --wrap=WRAP", last=True)
+        options = self.help_check(options, "-w WRAP, --wrap=WRAP", last=True)
