@@ -1,20 +1,17 @@
 #!/usr/bin/env python
 
 from translate.convert import po2xliff
-from translate.misc import wStringIO
 from translate.storage import po
 from translate.storage import poxliff
 from translate.storage import lisa
-from xml.parsers.xmlproc import xmlval, xmlproc
-from py import test
 
 class TestPO2XLIFF:
 
     def po2xliff(self, posource, sourcelanguage='en', targetlanguage=None):
         """helper that converts po source to xliff source without requiring files"""
-        pofile = po.pofile(posource)
+        postore = po.pofile(posource)
         convertor = po2xliff.po2xliff()
-        outputxliff = convertor.convertfile(pofile, None, sourcelanguage=sourcelanguage, targetlanguage=targetlanguage)
+        outputxliff = convertor.convertstore(postore, None, sourcelanguage=sourcelanguage, targetlanguage=targetlanguage)
         return poxliff.PoXliffFile(outputxliff)
 
     def getnode(self, xliff):
@@ -58,7 +55,8 @@ msgstr "Toepassings"
         assert xliff.translate("Applications") == "Toepassings"
         assert xliff.translate("bla") is None
         xmltext = str(xliff)
-        assert xmltext.index('<xliff version="1.1"')
+        assert xmltext.index('<xliff ') >= 0
+        assert xmltext.index(' version="1.1"') >= 0
         assert xmltext.index('<file')
         assert xmltext.index('source-language')
         assert xmltext.index('datatype')
@@ -121,14 +119,14 @@ msgstr "Gebruik \\\"."
         print xmltext
         assert xliff.translate('Hello "Everyone"') == 'Good day "All"'
         assert xliff.translate(r'Use \".') == r'Gebruik \".'
-        assert xmltext.find(r'\&quot;') > 0
+        assert xmltext.find(r'\&quot;') > 0 or xmltext.find(r'\"') > 0
         assert xmltext.find(r"\\") == -1
 
-    def getcontexttuples(self, node):
+    def getcontexttuples(self, node, namespace):
         """Returns all the information in the context nodes as a list of tuples
         of (type, text)"""
-        contexts = node.getElementsByTagName("context")
-        return [(context.getAttribute("context-type"), lisa.getText([context])) for context in contexts]
+        contexts = node.findall(".//{%s}context" % namespace)
+        return [(context.get("context-type"), lisa.getText(context)) for context in contexts]
 
     def test_locationcomments(self):
         minipo = r'''#: file.c:123 asdf.c
@@ -142,12 +140,12 @@ msgstr "kunye"
         assert xliff.translate("one") == "kunye"
         assert len(xliff.units) == 1
         node = xliff.units[0].xmlelement
-        contextgroups = node.getElementsByTagName("context-group")
+        contextgroups = node.findall(".//%s" % xliff.namespaced("context-group"))
         assert len(contextgroups) == 2
         for group in contextgroups:
-            assert group.getAttribute("name") == "po-reference"
-            assert group.getAttribute("purpose") == "location"
-        tuples = self.getcontexttuples(node)
+            assert group.get("name") == "po-reference"
+            assert group.get("purpose") == "location"
+        tuples = self.getcontexttuples(node, xliff.namespace)
         assert tuples == [("sourcefile", "file.c"), ("linenumber", "123"), ("sourcefile", "asdf.c")]
 
     def test_othercomments(self):
@@ -163,12 +161,12 @@ msgstr "kunye"
         assert xliff.translate("one") == "kunye"
         assert len(xliff.units) == 1
         node = xliff.units[0].xmlelement
-        contextgroups = node.getElementsByTagName("context-group")
+        contextgroups = node.findall(".//%s" % xliff.namespaced("context-group"))
         assert len(contextgroups) == 1
         for group in contextgroups:
-            assert group.getAttribute("name") == "po-entry"
-            assert group.getAttribute("purpose") == "information"
-        tuples = self.getcontexttuples(node)
+            assert group.get("name") == "po-entry"
+            assert group.get("purpose") == "information"
+        tuples = self.getcontexttuples(node, xliff.namespace)
         assert tuples == [("x-po-trancomment", "Translate?\nHow?")]
 
         assert xliff.units[0].getnotes("translator") == "Translate?\nHow?"
@@ -187,12 +185,12 @@ msgstr "kunye"
         assert xliff.translate("one") == "kunye"
         assert len(xliff.units) == 1
         node = xliff.units[0].xmlelement
-        contextgroups = node.getElementsByTagName("context-group")
+        contextgroups = node.findall(".//%s" % xliff.namespaced("context-group"))
         assert len(contextgroups) == 1
         for group in contextgroups:
-            assert group.getAttribute("name") == "po-entry"
-            assert group.getAttribute("purpose") == "information"
-        tuples = self.getcontexttuples(node)
+            assert group.get("name") == "po-entry"
+            assert group.get("purpose") == "information"
+        tuples = self.getcontexttuples(node, xliff.namespace)
         assert tuples == [("x-po-autocomment", "Don't translate.\nPlease")]
 
     def test_header(self):
@@ -210,9 +208,9 @@ msgstr ""
         assert len(xliff.units) == 1
         unit = xliff.units[0]
         assert unit.source == unit.target == "MIME-Version: 1.0\n"
-        assert unit.xmlelement.getAttribute("restype") == "x-gettext-domain-header"
-        assert unit.xmlelement.getAttribute("approved") == "no"
-        assert unit.xmlelement.getAttribute("xml:space") == "preserve"
+        assert unit.xmlelement.get("restype") == "x-gettext-domain-header"
+        assert unit.xmlelement.get("approved") == "no"
+        assert unit.xmlelement.get("{%s}space" % lisa.XML_NS) == "preserve"
         assert unit.getnotes("po-translator") == "Pulana  Translation for bla\nHallo Ma!"
 
     def test_fuzzy(self):
@@ -273,3 +271,26 @@ msgstr "%s%s%s%s het %s sy/haar vriend/vriendin gemaak%s%s"'''
         print xliff.units[0].source
         assert xliff.units[0].source == "%s%s%s%s has made %s his or her buddy%s%s"
 
+    def test_approved(self):
+        minipo = r'''#, fuzzy
+msgid "two"
+msgstr "pedi"
+
+msgid "three"
+msgstr "raro"
+
+msgid "four"
+msgstr ""
+'''
+        xliff = self.po2xliff(minipo)
+        print "The generated xml:"
+        xmltext = str(xliff)
+        print xmltext
+        assert len(xliff.units) == 3
+        assert xliff.units[0].xmlelement.get("approved") == "no"
+        assert not xliff.units[0].isapproved()
+        assert xliff.units[1].xmlelement.get("approved") == "yes"
+        assert xliff.units[1].isapproved()
+        assert xliff.units[2].xmlelement.get("approved") == "no"
+        assert not xliff.units[2].isapproved()
+
