@@ -4,7 +4,6 @@ from translate.convert import pot2po
 from translate.convert import test_convert
 from translate.misc import wStringIO
 from translate.storage import po
-from py import test
 import warnings
 
 class TestPOT2PO:
@@ -35,24 +34,72 @@ class TestPOT2PO:
 
     def test_convertpot_blank(self):
         """checks that the convertpot function is working for a simple file initialisation"""
-        potsource = '''#: simple.label\n#: simple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr ""\n'''
+        potsource = '''#: simple.label%ssimple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr ""\n''' % po.lsep
         newpo = self.convertpot(potsource)
         assert str(self.singleunit(newpo)) == potsource
 
+    def test_convertpot_blank_plurals(self):
+        """checks that the convertpot function is working for initialising plurals correctly"""
+        potsource = r'''msgid ""
+msgstr""
+
+msgid "%d manual"
+msgid_plural "%d manuals"
+msgstr[0] ""
+msgstr[1] ""
+'''
+        posource = r'''msgid ""
+msgstr""
+"Plural-Forms: nplurals=1; plural=0;\n"
+'''
+
+        poexpected = r'''msgid "%d manual"
+msgid_plural "%d manuals"
+msgstr[0] ""
+'''
+        newpo = self.convertpot(potsource, posource)
+        assert str(self.singleunit(newpo)) == poexpected
+
     def test_merging_simple(self):
         """checks that the convertpot function is working for a simple merge"""
-        potsource = '''#: simple.label\n#: simple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr ""\n'''
-        posource = '''#: simple.label\n#: simple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n'''
+        potsource = '''#: simple.label%ssimple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr ""\n''' % po.lsep
+        posource = '''#: simple.label%ssimple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n''' % po.lsep
         newpo = self.convertpot(potsource, posource)
         assert str(self.singleunit(newpo)) == posource
 
     def test_merging_messages_marked_fuzzy(self):
         """test that when we merge PO files with a fuzzy message that it remains fuzzy"""
-        potsource = '''#: simple.label\n#: simple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr ""\n'''
-        posource = '''#: simple.label\n#: simple.accesskey\n#, fuzzy\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n'''
+        potsource = '''#: simple.label%ssimple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr ""\n''' % po.lsep
+        posource = '''#: simple.label%ssimple.accesskey\n#, fuzzy\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n''' % po.lsep
         newpo = self.convertpot(potsource, posource)
         assert str(self.singleunit(newpo)) == posource
 
+    def test_merging_plurals_with_fuzzy_matching(self):
+        """test that when we merge PO files with a fuzzy message that it remains fuzzy"""
+        potsource = r'''#: file.cpp:2
+msgid "%d manual"
+msgid_plural "%d manuals"
+msgstr[0] ""
+msgstr[1] ""
+'''
+        posource = r'''#: file.cpp:3
+#, fuzzy
+msgid "%d manual"
+msgid_plural "%d manuals"
+msgstr[0] "%d handleiding."
+msgstr[1] "%d handleidings."
+'''
+        # The #: comment and msgid's are different between the pot and the po
+        poexpected = r'''#: file.cpp:2
+#, fuzzy
+msgid "%d manual"
+msgid_plural "%d manuals"
+msgstr[0] "%d handleiding."
+msgstr[1] "%d handleidings."
+'''
+        newpo = self.convertpot(potsource, posource)
+        assert str(self.singleunit(newpo)) == poexpected
+
     def xtest_merging_msgid_change(self):
         """tests that if the msgid changes but the location stays the same that we merge"""
         potsource = '''#: simple.label\n#: simple.accesskey\nmsgid "Its &hard coding a newline.\\n"\nmsgstr ""\n'''
@@ -64,18 +111,18 @@ class TestPOT2PO:
 
     def test_merging_location_change(self):
         """tests that if the location changes but the msgid stays the same that we merge"""
-        potsource = '''#: new_simple.label\n#: new_simple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr ""\n'''
-        posource = '''#: simple.label\n#: simple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n'''
-        poexpected = '''#: new_simple.label\n#: new_simple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n'''
+        potsource = '''#: new_simple.label%snew_simple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr ""\n''' % po.lsep
+        posource = '''#: simple.label%ssimple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n''' % po.lsep
+        poexpected = '''#: new_simple.label%snew_simple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n''' % po.lsep
         newpo = self.convertpot(potsource, posource)
         print newpo
         assert str(self.singleunit(newpo)) == poexpected
 
     def test_merging_location_and_whitespace_change(self):
         """test that even if the location changes that if the msgid only has whitespace changes we can still merge"""
-        potsource = '''#: singlespace.label\n#: singlespace.accesskey\nmsgid "&We have spaces"\nmsgstr ""\n'''
-        posource = '''#: doublespace.label\n#: doublespace.accesskey\nmsgid "&We  have  spaces"\nmsgstr "&One  het  spasies"\n'''
-        poexpected = '''#: singlespace.label\n#: singlespace.accesskey\n#, fuzzy\nmsgid "&We have spaces"\nmsgstr "&One  het  spasies"\n'''
+        potsource = '''#: singlespace.label%ssinglespace.accesskey\nmsgid "&We have spaces"\nmsgstr ""\n''' % po.lsep
+        posource = '''#: doublespace.label%sdoublespace.accesskey\nmsgid "&We  have  spaces"\nmsgstr "&One  het  spasies"\n''' % po.lsep
+        poexpected = '''#: singlespace.label%ssinglespace.accesskey\n#, fuzzy\nmsgid "&We have spaces"\nmsgstr "&One  het  spasies"\n''' % po.lsep
         newpo = self.convertpot(potsource, posource)
         print newpo
         assert str(self.singleunit(newpo)) == poexpected
@@ -136,6 +183,28 @@ class TestPOT2PO:
         newpounit = self.singleunit(newpo)
         assert str(newpounit) == poexpected
 
+    def test_empty_commentlines(self):
+        potsource = '''#: paneSecurity.title
+msgid "Security"
+msgstr ""
+'''
+        posource = '''# - Contributor(s):
+# -
+# - Alternatively, the
+# -
+#: paneSecurity.title
+msgid "Security"
+msgstr "Sekuriteit"
+'''
+        poexpected = posource
+        newpo = self.convertpot(potsource, posource)
+        newpounit = self.singleunit(newpo)
+        print "expected"
+        print poexpected
+        print "got:"
+        print str(newpounit)
+        assert str(newpounit) == poexpected
+
     def test_merging_msgidcomments(self):
         """ensure that we can merge msgidcomments messages"""
         potsource = r'''#: window.width
@@ -202,7 +271,7 @@ msgstr "Sertifikate"
     def test_merging_obsoleting_messages(self):
         """check that we obsolete messages no longer present in the new file"""
         potsource = ''
-        posource = '# Some comment\n#: obsoleteme:10\nmsgid "One"\nmsgstr "Een"\n'
+        posource = '# Some comment\n#. Extracted comment\n#: obsoleteme:10\nmsgid "One"\nmsgstr "Een"\n'
         expected = '# Some comment\n#~ msgid "One"\n#~ msgstr "Een"\n'
         newpo = self.convertpot(potsource, posource)
         print str(newpo)
@@ -226,8 +295,8 @@ msgstr "Sertifikate"
         assert len(newpo.units) == 3
         assert newpo.units[0].isheader()
         assert newpo.units[2].isobsolete()
-        newpo.units = newpo.units[1:]
-        assert str(newpo) == potsource + "\n" + posource
+        assert str(newpo.units[1]) == potsource
+        assert str(newpo.units[2]) == posource
 
         # Now test with real units present in posource
         posource2 = '''msgid "Old"\nmsgstr "Oud"\n'''
@@ -235,8 +304,8 @@ msgstr "Sertifikate"
         assert len(newpo.units) == 3
         assert newpo.units[0].isheader()
         assert newpo.units[2].isobsolete()
-        newpo.units = newpo.units[1:]
-        assert str(newpo) == potsource + "\n" + posource
+        assert str(newpo.units[1]) == potsource
+        assert str(newpo.units[2]) == posource
 
     def test_merging_resurect_obsolete_messages(self):
         """check that we can reuse old obsolete messages if the message comes back"""
@@ -324,6 +393,24 @@ msgstr ""
         newpounit = self.singleunit(newpo)
         assert str(newpounit) == poexpected
         
+    def test_merging_typecomments(self):
+        """Test that we can merge with typecomments"""
+        potsource = '''#: file.c:1\n#, c-format\nmsgid "%d pipes"\nmsgstr ""\n''' 
+        posource = '''#: file.c:2\nmsgid "%d pipes"\nmsgstr "%d pype"\n'''
+        poexpected = '''#: file.c:1\n#, c-format\nmsgid "%d pipes"\nmsgstr "%d pype"\n'''
+        newpo = self.convertpot(potsource, posource)
+        newpounit = self.singleunit(newpo)
+        print newpounit
+        assert str(newpounit) == poexpected
+
+        potsource = '''#: file.c:1\n#, c-format\nmsgid "%d computers"\nmsgstr ""\n''' 
+        posource = '''#: file.c:2\n#, c-format\nmsgid "%s computers "\nmsgstr "%s-rekenaars"\n'''
+        poexpected = '''#: file.c:1\n#, fuzzy, c-format\nmsgid "%d computers"\nmsgstr "%s-rekenaars"\n'''
+        newpo = self.convertpot(potsource, posource)
+        newpounit = self.singleunit(newpo)
+        assert newpounit.isfuzzy()
+        assert newpounit.hastypecomment("c-format")
+
 class TestPOT2POCommand(test_convert.TestConvertCommand, TestPOT2PO):
     """Tests running actual pot2po commands on files"""
     convertmodule = pot2po
@@ -331,8 +418,9 @@ class TestPOT2POCommand(test_convert.TestConvertCommand, TestPOT2PO):
     def test_help(self):
         """tests getting help"""
         options = test_convert.TestConvertCommand.test_help(self)
-        options = self.help_check(options, "-tTEMPLATE, --template=TEMPLATE")
+        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "-P, --pot")
         options = self.help_check(options, "--tm")
-        options = self.help_check(options, "-sMIN_SIMILARITY, --similarity=MIN_SIMILARITY")
+        options = self.help_check(options, "-s MIN_SIMILARITY, --similarity=MIN_SIMILARITY")
+        options = self.help_check(options, "--nofuzzymatching", last=True)
 
