@@ -16,9 +16,9 @@ class TestProp2PO:
         if proptemplate:
           templatefile = wStringIO.StringIO(proptemplate)
           templateprop = properties.propfile(templatefile)
-          outputpo = convertor.mergefiles(templateprop, inputprop)
+          outputpo = convertor.mergestore(templateprop, inputprop)
         else:
-          outputpo = convertor.convertfile(inputprop)
+          outputpo = convertor.convertstore(inputprop)
         return outputpo
 
     def convertprop(self, propsource):
@@ -48,7 +48,7 @@ class TestProp2PO:
         pofile = self.prop2po(propsource)
         pounit = self.singleelement(pofile)
         assert pounit.source == "Save file"
-        assert po.unquotefrompo(pounit.msgstr) == ""
+        assert pounit.target == ""
 
     def test_convertprop(self):
         """checks that the convertprop function is working"""
@@ -57,14 +57,7 @@ class TestProp2PO:
         pofile = po.pofile(wStringIO.StringIO(posource))
         pounit = self.singleelement(pofile)
         assert pounit.source == "Save file"
-        assert po.unquotefrompo(pounit.msgstr) == ""
-
-    def test_emptyentry(self):
-        """checks that an empty properties entry survive into the po file, bug 15"""
-        propsource = 'CONFIGENTRY=\n'
-        pofile = self.prop2po(propsource)
-        pounit = self.singleelement(pofile)
-        assert "CONFIGENTRY" in str(pounit)
+        assert pounit.target == ""
 
     def test_tab_at_end_of_string(self):
         """check that we preserve tabs at the end of a string"""
@@ -102,8 +95,8 @@ class TestProp2PO:
         propsource = 'nb = %s\n' % unistring
         pofile = self.prop2po(propsource)
         pounit = self.singleelement(pofile)
-        print repr(pofile.units[0].msgstr)
-        print repr(pounit.msgid)
+        print repr(pofile.units[0].target)
+        print repr(pounit.source)
         assert pounit.source == u'Norsk bokm\u00E5l'
 
     def test_multiline_escaping(self):
@@ -112,7 +105,7 @@ class TestProp2PO:
 of connections to this server. If so, use the Advanced IMAP Server Settings dialog to \
 reduce the number of cached connections."""
         pofile = self.prop2po(propsource)
-        print repr(pofile.units[1].msgstr)
+        print repr(pofile.units[1].target)
         assert self.countelements(pofile) == 1
 
     def test_comments(self):
@@ -121,8 +114,7 @@ reduce the number of cached connections."""
 prefPanel-smime=Security'''
         pofile = self.prop2po(propsource)
         pounit = self.singleelement(pofile)
-        # FIXME This should probably become "#. Comment" to be fully correct in PO format
-        assert pounit.othercomments == ["# Comment\n"]
+        assert pounit.getnotes("developer") == "# Comment"
 
     def wtest_folding_accesskeys(self):
         """check that we can fold various accesskeys into their associated label (bug #115)"""
@@ -134,40 +126,34 @@ cmd_addEngine_accesskey = A'''
 
     def test_dont_translate(self):
         """check that we know how to ignore don't translate instructions in properties files (bug #116)"""
-        propsource = '''# LOCALIZATION NOTE (1029): DONT_TRANSLATE.
-1029=forward.msg
+        propsource = '''# LOCALIZATION NOTE (dont): DONT_TRANSLATE.
+dont=don't translate me
+do=translate me
 '''
         pofile = self.prop2po(propsource)
-        assert self.countelements(pofile) == 0
-
-    def wtest_localization_notes(self):
-        """check that we fold localisation notes into KDE comments"""
-        propsource = '''# Description of import module
-## @name OUTLOOKIMPORT_DESCRIPTION
-## @loc None
-## LOCALIZATION NOTE (2001): In this item, don't translate "Outlook"
-2001=Outlook mail and address books
-'''
-        pofile = self.prop2po(propsource)
-        pounit = self.singleelement(pofile)
-        assert pounit.source == '''_: In this item, don't translate "Outlook"\\n\nOutlook mail and address books'''
+        assert self.countelements(pofile) == 1
 
     def test_emptyproperty(self):
-        """checks that empty property definitions survive into po file"""
+        """checks that empty property definitions survive into po file, bug 15"""
         propsource = '# comment\ncredit='
         pofile = self.prop2po(propsource)
         pounit = self.singleelement(pofile)
-        assert "credit" in str(pounit)
+        assert pounit.getlocations() == ["credit"]
+        assert pounit.getcontext() == "credit"
+        assert "#. # comment" in str(pofile)
+        assert pounit.source == ""
 
     def test_emptyproperty_translated(self):
         """checks that if we translate an empty property it makes it into the PO"""
         proptemplate = 'credit='
         propsource = 'credit=Translators Names'
         pofile = self.prop2po(propsource, proptemplate)
-        unit = self.singleelement(pofile)
-        print unit
-        assert "credit" in str(unit)
-        assert unit.target == "Translators Names"
+        pounit = self.singleelement(pofile)
+        assert pounit.getlocations() == ["credit"]
+        # FIXME we don't seem to get a _: comment but we should
+        #assert pounit.getcontext() == "credit"
+        assert pounit.source == ""
+        assert pounit.target == "Translators Names"
 
     def test_newlines_in_value(self):
         """check that we can carry newlines that appear in the property value into the PO"""
@@ -178,10 +164,19 @@ cmd_addEngine_accesskey = A'''
 
     def test_unassociated_comments(self):
         """check that we can handle comments not directly associated with a property"""
-        propsource = '''#### Commnet\n\nprop=value\n'''
+        propsource = '''# Header comment\n\n# Comment\n\nprop=value\n'''
         pofile = self.prop2po(propsource)
         unit = self.singleelement(pofile)
         assert unit.source == "value"
+        assert unit.getnotes("developer") == "# Comment"
+
+    def test_unassociated_comment_order(self):
+        """check that we can handle the order of unassociated comments"""
+        propsource = '''# Header comment\n\n# 1st Unassociated comment\n\n# 2nd Connected comment\nprop=value\n'''
+        pofile = self.prop2po(propsource)
+        unit = self.singleelement(pofile)
+        assert unit.source == "value"
+        assert unit.getnotes("developer") == "# 1st Unassociated comment\n# 2nd Connected comment"
 
 class TestProp2POCommand(test_convert.TestConvertCommand, TestProp2PO):
     """Tests running actual prop2po commands on files"""
@@ -192,6 +187,6 @@ class TestProp2POCommand(test_convert.TestConvertCommand, TestProp2PO):
         """tests getting help"""
         options = test_convert.TestConvertCommand.test_help(self)
         options = self.help_check(options, "-P, --pot")
-        options = self.help_check(options, "-tTEMPLATE, --template=TEMPLATE")
+        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "--duplicates=DUPLICATESTYLE", last=True)
 
