@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 
 from translate.convert import xliff2po
-from translate.storage import po
 from translate.misc import wStringIO
 
 class TestXLIFF2PO:
@@ -17,9 +16,10 @@ class TestXLIFF2PO:
     def xliff2po(self, xliffsource):
         """helper that converts xliff source to po source without requiring files"""
         inputfile = wStringIO.StringIO(xliffsource)
-	convertor = xliff2po.xliff2po()
-	outputpo = convertor.convertfile(inputfile)
+        convertor = xliff2po.xliff2po()
+        outputpo = convertor.convertstore(inputfile)
         print "The generated po:"
+        print type(outputpo)
         print str(outputpo)
         return outputpo
 	
@@ -54,13 +54,14 @@ Content-Transfer-Encoding: 8bit'''
     <target>utshani</target>
   </trans-unit>''') % (headertext, headertext)
 
+        print minixlf
         pofile = self.xliff2po(minixlf)
         assert pofile.translate("gras") == "utshani"
         assert pofile.translate("bla") is None
         potext = str(pofile)
-	assert potext.index('# Zulu translation of program ABC') == 0
-	assert potext.index('msgid "gras"\n')
-	assert potext.index('msgstr "utshani"\n')
+        assert potext.index('# Zulu translation of program ABC') == 0
+        assert potext.index('msgid "gras"\n')
+        assert potext.index('msgstr "utshani"\n')
         assert potext.index('MIME-Version: 1.0\\n')
 
     def test_translatorcomments(self):
@@ -80,7 +81,6 @@ it</note>
         assert pofile.translate("bla") is None
         unit = pofile.units[0]
         assert unit.getnotes("translator") == "Couldn't do\nit"
-        assert unit.othercomments == ["# Couldn't do\n", "# it\n"]
         potext = str(pofile)
         assert potext.index("# Couldn't do\n# it\n") >= 0
 
@@ -101,7 +101,6 @@ garbage</note>
         assert pofile.translate("bla") is None
         unit = pofile.units[0]
         assert unit.getnotes("developer") == "Note that this is\ngarbage"
-        assert unit.automaticcomments == ["#. Note that this is\n", "#. garbage\n"]
         potext = str(pofile)
         assert potext.index("#. Note that this is\n#. garbage\n") >= 0
 
@@ -164,9 +163,22 @@ garbage</note>
         </trans-unit>
 </group>'''
         pofile = self.xliff2po(minixlf)
+        print str(pofile)
         potext = str(pofile)
         assert len(pofile.units) == 1
         assert potext.index('msgid_plural "cows"')
         assert potext.index('msgstr[0] "inkomo"')
         assert potext.index('msgstr[1] "iinkomo"')
 
+
+class TestBasicXLIFF2PO(TestXLIFF2PO):
+    """This tests a basic XLIFF file without xmlns attribute"""
+
+    xliffskeleton = '''<?xml version="1.0" ?>
+<xliff version="1.1">
+  <file original="filename.po" source-language="en-US" datatype="po">
+    <body>
+        %s
+    </body>
+  </file>
+</xliff>'''
