@@ -1,22 +1,31 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from translate.storage import po
-from translate.storage import xliff
+from translate.storage import factory
 from translate.filters import pofilter
 from translate.filters import checks
 from translate.misc import wStringIO
 
 class BaseTestFilter(object):
     """Base class for filter tests."""
+
+    filename = ""
+
+    def parse_text(self, filetext):
+        """helper that parses xliff file content without requiring files"""
+        dummyfile = wStringIO.StringIO(filetext)
+        dummyfile.name = self.filename
+        store = factory.getobject(dummyfile)
+        return store
+
     def filter(self, translationstore, checkerconfig=None, cmdlineoptions=None):
         """Helper that passes a translations store through a filter, and returns the resulting store."""
         if cmdlineoptions is None:
             cmdlineoptions = []
-        options, args = pofilter.cmdlineparser().parse_args(["xxx.po"] + cmdlineoptions)
-        checkerclasses = [checks.StandardChecker, pofilter.StandardPOChecker]
+        options, args = pofilter.cmdlineparser().parse_args([self.filename] + cmdlineoptions)
+        checkerclasses = [checks.StandardChecker, checks.StandardUnitChecker]
         if checkerconfig is None:
-          checkerconfig = checks.CheckerConfig()
+            checkerconfig = checks.CheckerConfig()
         checkfilter = pofilter.pocheckfilter(options, checkerclasses, checkerconfig)
         tofile = checkfilter.filterfile(translationstore)
         return tofile
@@ -28,20 +37,20 @@ class BaseTestFilter(object):
 
     def test_simplefail(self):
         """checks that an obviously wrong string fails"""
-        self.unit.settarget("REST")
+        self.unit.target = "REST"
         filter_result = self.filter(self.translationstore)
         assert filter_result.units[0].geterrors().has_key('startcaps')
 
     def test_variables_across_lines(self):
         """Test that variables can span lines and still fail/pass"""
-        self.unit.setsource('"At &timeBombURL."\n"label;."')
-        self.unit.settarget('"Tydens &tydBombURL."\n"etiket;."')
+        self.unit.source = '"At &timeBombURL."\n"label;."'
+        self.unit.target = '"Tydens &tydBombURL."\n"etiket;."'
         filter_result = self.filter(self.translationstore)
         assert len(filter_result.units) == 0
 
     def test_ignore_if_already_marked(self):
         """check that we don't add another failing marker if the message is already marked as failed"""
-        self.unit.settarget('')
+        self.unit.target = ''
         filter_result = self.filter(self.translationstore, cmdlineoptions=["--test=untranslated"])
         errors = filter_result.units[0].geterrors()
         assert len(errors) == 1
@@ -124,29 +133,34 @@ class BaseTestFilter(object):
 
     def test_unicode(self):
         """tests that we can handle UTF-8 encoded characters when there is no known header specified encoding"""
-        self.unit.setsource(u'Bézier curve')
-        self.unit.settarget(u'Bézier-kurwe')
+        self.unit.source = u'Bézier curve'
+        self.unit.target = u'Bézier-kurwe'
         filter_result = self.filter(self.translationstore)
         assert len(filter_result.units) == 0
 
+    def test_preconditions(self):
+        """tests that the preconditions work correctly"""
+        self.unit.source = "File"
+        self.unit.target = ""
+        filter_result= self.filter(self.translationstore)
+        # We should only get one error (untranslated), and nothing else
+        assert len(filter_result.units) == 1
+        unit = filter_result.units[0]
+        assert len(unit.geterrors()) == 1
+
 class TestPOFilter(BaseTestFilter):
     """Test class for po-specific tests."""
     filetext = '#: test.c\nmsgid "test"\nmsgstr "rest"\n'
-
-    def poparse(self, posource):
-        """helper that parses po source without requiring files"""
-        dummyfile = wStringIO.StringIO(posource)
-        pofile = po.pofile(dummyfile)
-        return pofile
+    filename = 'test.po'
 
     def setup_method(self, method):
-        self.translationstore = self.poparse(self.filetext)
+        self.translationstore = self.parse_text(self.filetext)
         self.unit = self.translationstore.units[0]
 
     def test_msgid_comments(self):
         """Tests that msgid comments don't feature anywhere."""
         posource = 'msgid "_: Capital.  ACRONYMN. (msgid) comment 3. %d Extra sentence.\\n"\n"cow"\nmsgstr "koei"\n'
-        pofile = self.poparse(posource)
+        pofile = self.parse_text(posource)
         filter_result = self.filter(pofile)
         if len(filter_result.units):
             print filter_result.units[0]
@@ -165,12 +179,7 @@ class TestXliffFilter(BaseTestFilter):
   </body>
 </file>
 </xliff>'''
-
-    def xliffparse(self, filetext):
-        """helper that parses xliff file content without requiring files"""
-        dummyfile = wStringIO.StringIO(filetext)
-        xliffstore = xliff.xlifffile(dummyfile)
-        return xliffstore
+    filename = "test.xlf"
 
     def set_store_review(review=True):
         self.filetext = '''<?xml version="1.0" encoding="utf-8"?>
@@ -185,9 +194,48 @@ class TestXliffFilter(BaseTestFilter):
 </file>
 </xliff>'''
 
-        self.translationstore = self.xliffparse(self.filetext)
+        self.translationstore = self.parse_text(self.filetext)
         self.unit = self.translationstore.units[0]
 
     def setup_method(self, method):
-        self.translationstore = self.xliffparse(self.filetext)
+        self.translationstore = self.parse_text(self.filetext)
         self.unit = self.translationstore.units[0]
+
+class TestTMXFilter(BaseTestFilter):
+    """Test class for TMX-specific tests."""
+    filetext = '''<!DOCTYPE tmx SYSTEM "tmx14.dtd">
+<tmx version="1.4">
+  <header creationtool="Translate Toolkit - po2tmx" creationtoolversion="1.1.1rc1" segtype="sentence" o-tmf="UTF-8" adminlang="en" srclang="en
+" datatype="PlainText"/>
+  <body>
+    <tu>
+      <tuv xml:lang="en">
+        <seg>test</seg>
+      </tuv>
+      <tuv xml:lang="af">
+        <seg>rest</seg>
+      </tuv>
+    </tu>
+  </body>
+</tmx>'''
+    filename = "test.tmx"
+
+    def setup_method(self, method):
+        self.translationstore = self.parse_text(self.filetext)
+        self.unit = self.translationstore.units[0]
+
+    def test_test_against_fuzzy(self):
+        """TMX doesn't support fuzzy"""
+        pass
+
+    def test_test_against_review(self):
+        """TMX doesn't support review"""
+        pass
+
+    def test_isfuzzy(self):
+        """TMX doesn't support fuzzy"""
+        pass
+
+    def test_isreview(self):
+        """TMX doesn't support review"""
+        pass
