@@ -33,11 +33,13 @@ class ar(common.Common):
     nplurals = 6
     pluralequation = "n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n>=3 && n<=10 ? 3 : n>=11 && n<=99 ? 4 : 5"
 
+    listseperator = u"، "
+
     puncdict = {
         u",": u"،",
         u";": u"؛",
         u"?": u"؟",
-        u"%": u"÷",
+        u"%": u"٪",
     }
 
     ignoretests = ["startcaps", "simplecaps"]
