@@ -21,6 +21,8 @@
 
 """This module stores information and functionality that relates to plurals."""
 
+import unicodedata
+
 # The key is the language code, which may contain country codes and modifiers.
 # The value is a tuple: (Full name in English, nplurals, plural equation)
 
@@ -60,7 +62,7 @@ languages = {
 'he': ('Hebrew', 2, '(n != 1)'),
 'hi': ('Hindi', 2, '(n != 1)'),
 'hr': ('Croatian', 3, '(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2)'),
-'hu': ('Hungarian', 1, '0'),
+'hu': ('Hungarian', 2, '(n != 1)'),
 'id': ('Indonesian', 1, '0'),
 'is': ('Icelandic', 2, '(n != 1)'),
 'it': ('Italian', 2, '(n != 1)'),
@@ -73,6 +75,7 @@ languages = {
 'ln': ('Lingala', 2, '(n > 1)'),
 'lt': ('Lithuanian', 3, '(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2)'),
 'lv': ('Latvian', 3, '(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2)'),
+'mg': ('Malagasy', 2, '(n > 1)'),
 'mn': ('Mongolian', 2, '(n != 1)'),
 'mr': ('Marathi', 2, '(n != 1)'),
 'ms': ('Malay', 1, '0'),
@@ -85,6 +88,7 @@ languages = {
 'nso': ('Northern Sotho', 2, '(n > 1)'),
 'or': ('Oriya', 2, '(n != 1)'),
 'pa': ('Punjabi', 2, '(n != 1)'),
+'pap': ('Papiamento', 2, '(n != 1)'),
 'pl': ('Polish', 3, '(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2)'),
 'pt': ('Portugese', 2, '(n != 1)'),
 'pt_BR': ('Portugese (Brazil)', 2, '(n > 1)'),
@@ -96,12 +100,13 @@ languages = {
 'sr': ('Serbian', 3, '(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2)'),
 'sv': ('Swedish', 2, '(n != 1)'),
 'ta': ('Tamil', 2, '(n != 1)'),
+'th': ('Thai', 1, '0'),
 'tk': ('Turkmen', 2, '(n != 1)'),
 'tr': ('Turkish', 1, '0'),
 'uk': ('Ukrainian', 3, '(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2)'),
 'vi': ('Vietnamese',1 , '0'),
 'wa': ('Walloon', 2, '(n > 1)'),
-# Chinese is diffictult because the main devide is on script, not really 
+# Chinese is difficult because the main divide is on script, not really 
 # country. Simplified Chinese is used mostly in China, Singapore and Malaysia.
 # Traditional Chinese is used mostly in Hong Kong, Taiwan and Macau.
 'zh_CN': ('Chinese (China)', 1, '0'),
@@ -112,9 +117,14 @@ languages = {
 def simplercode(code):
     """This attempts to simplify the given language code by ignoring country 
     codes, for example."""
+    # Check http://www.rfc-editor.org/rfc/bcp/bcp47.txt for possible extra issues
+    # http://www.rfc-editor.org/rfc/rfc4646.txt
+    # http://www.w3.org/International/articles/language-tags/
     if not code:
         return code
 
+    # The @ modifier is used for script variants of the same language, like 
+    # sr@Latn or gez_ER@abegede
     modifier = code.rfind("@")
     if modifier >= 0:
         return code[:modifier]
@@ -165,3 +175,22 @@ def gettext_country(langcode):
         iso3166[langcode] = t.ugettext
     return iso3166[langcode]
 
+def normalize(string, normal_form="NFC"):
+    """Return a unicode string in its normalized form
+    
+    @param sting: The string to be normalized
+    @param normal_form: NFC (default), NFD, NFCK, NFDK
+    @return: Normalized string
+    """
+    return unicodedata.normalize(normal_form, string)
+
+def forceunicode(string):
+    """Helper method to ensure that the parameter becomes unicode if not yet"""
+    if string is None:
+        return None
+    if isinstance(string, str):
+        encoding = getattr(string, "encoding", "utf-8")
+        string = string.decode(encoding)
+    string = normalize(string)
+    return string
+    
