@@ -24,6 +24,8 @@
 For more information, see U{http://en.wikipedia.org/wiki/Greek_language}
 """
 
+import re
+
 from translate.lang import common
 
 class el(common.Common):
@@ -34,8 +36,15 @@ class el(common.Common):
     pluralequation = "(n != 1)"
 
     # Greek uses ; as question mark and the middot instead
-    sentenceend = u".!;"
+    sentenceend = u".!;…"
 
+    sentencere = re.compile(r"""(?s)    #make . also match newlines
+                            .*?         #anything, but match non-greedy
+                            [%s]        #the puntuation for sentence ending
+                            \s+         #the spacing after the puntuation
+                            (?=[^a-z\d])#lookahead that next part starts with caps
+                            """ % sentenceend, re.VERBOSE)
+    
     puncdict = {
         u"?": u";",
         u";": u"·",
