@@ -33,13 +33,16 @@ class fa(common.Common):
     nplurals = 1
     pluralequation = "0"
 
+    listseperator = u"، "
+
     puncdict = {
         u",": u"،",
         u";": u"؛",
         u"?": u"؟",
-        u"%": u"÷",
+        u"%": u"٪",
     }
 
     ignoretests = ["startcaps", "simplecaps"]
     #TODO: check persian numerics
     #TODO: zwj and zwnj?
+    #French quoting?
