@@ -24,9 +24,10 @@
 For more information, see U{http://en.wikipedia.org/wiki/Armenian_language}
 """
 
-from translate.lang import common
 import re
 
+from translate.lang import common
+
 class hy(common.Common):
     """This class represents Armenian."""
     code = "hy"
@@ -34,9 +35,20 @@ class hy(common.Common):
     nplurals = 2
     pluralequation = "(n > 1)"
 
+    armenianpunc = u"։՝՜՞"
+
+    punctuation = u"".join([common.Common.commonpunc, common.Common.quotes, common.Common.miscpunc, armenianpunc])
+
+    sentenceend = u"։՝՜…"
+
+    sentencere = re.compile(r"""(?s)    #make . also match newlines
+                            .*?         #anything, but match non-greedy
+                            [%s]        #the puntuation for sentence ending
+                            \s+         #the spacing after the puntuation
+                            (?=[^a-z\d])#lookahead that next part starts with caps
+                            """ % sentenceend, re.VERBOSE)
     puncdict = {
-        u".": u"。",
-        u",": u"，",
+        u".": u"։",
         u":": u"՝",
         u"!": u"՜",
         u"?": u"՞",
