@@ -22,6 +22,7 @@
 """string processing utilities for extracting strings with various kinds of delimiters"""
 
 import logging
+import htmlentitydefs
 
 def find_all(searchin, substr):
   """returns a list of locations where substr occurs in searchin
@@ -35,7 +36,7 @@ def find_all(searchin, substr):
       location += len(substr)
   return locations
 
-def extract(source,startdelim,enddelim,escape=None,startinstring=False,allowreentry=True):
+def extract(source, startdelim, enddelim, escape=None, startinstring=False, allowreentry=True):
   """Extracts a doublequote-delimited string from a string, allowing for backslash-escaping
   returns tuple of (quoted string with quotes, still in string at end)"""
   # note that this returns the quote characters as well... even internally
@@ -85,28 +86,28 @@ def extract(source,startdelim,enddelim,escape=None,startinstring=False,allowreen
       lastpos = pos
   if instring:
     extracted += source[lastpos:]
-  return (extracted,instring)
+  return (extracted, instring)
 
-def extractfromlines(lines,startdelim,enddelim,escape):
+def extractfromlines(lines, startdelim, enddelim, escape):
   """Calls extract over multiple lines, remembering whether in the string or not"""
   result = ""
   instring = 0
   for line in lines:
-    (string,instring) = extract(line,startdelim,enddelim,escape,instring)
+    (string, instring) = extract(line, startdelim, enddelim, escape, instring)
     result += string
     if not instring: break
   return result
 
 def extractstr(source):
   "Extracts a doublequote-delimited string from a string, allowing for backslash-escaping"
-  (string,instring) = extract(source,'"','"','\\')
+  (string, instring) = extract(source, '"', '"', '\\')
   return string
 
 def extractcomment(lines):
   "Extracts <!-- > XML comments from lines"
-  return extractfromlines(lines,"<!--","-->",None)
+  return extractfromlines(lines, "<!--", "-->", None)
 
-def extractwithoutquotes(source,startdelim,enddelim,escape=None,startinstring=False,includeescapes=True,allowreentry=True):
+def extractwithoutquotes(source, startdelim, enddelim, escape=None, startinstring=False, includeescapes=True, allowreentry=True):
   """Extracts a doublequote-delimited string from a string, allowing for backslash-escaping
   includeescapes can also be a function that takes the whole escaped string and returns the replaced version"""
   instring = startinstring
@@ -154,17 +155,17 @@ def extractwithoutquotes(source,startdelim,enddelim,escape=None,startinstring=Fa
         for epos in escape_list:
           new_section += section[last_epos:epos]
           if callable_includeescapes:
-              replace_escape = includeescapes(section[epos:epos+lenescape+1])
-              # TODO: deprecate old method of returning boolean from includeescape, by removing this if block
-              if not isinstance(replace_escape, basestring):
-                  if replace_escape:
-                      replace_escape = section[epos:epos+lenescape+1]
-                  else:
-                      replace_escape = section[epos+lenescape:epos+lenescape+1]
-              new_section += replace_escape
-              last_epos = epos + lenescape + 1
+            replace_escape = includeescapes(section[epos:epos+lenescape+1])
+            # TODO: deprecate old method of returning boolean from includeescape, by removing this if block
+            if not isinstance(replace_escape, basestring):
+              if replace_escape:
+                replace_escape = section[epos:epos+lenescape+1]
+              else:
+                replace_escape = section[epos+lenescape:epos+lenescape+1]
+            new_section += replace_escape
+            last_epos = epos + lenescape + 1
           else:
-              last_epos = epos + lenescape
+            last_epos = epos + lenescape
         section = new_section + section[last_epos:]
       extracted += section
       instring = False
@@ -183,12 +184,12 @@ def extractwithoutquotes(source,startdelim,enddelim,escape=None,startinstring=Fa
       for epos in escape_list:
         new_section += section[last_epos:epos]
         if callable_includeescapes and includeescapes(section[epos:epos+lenescape+1]):
-            last_epos = epos
+          last_epos = epos
         else:
-            last_epos = epos + lenescape
+          last_epos = epos + lenescape
       section = new_section + section[last_epos:]
     extracted += section
-  return (extracted,instring)
+  return (extracted, instring)
 
 def escapequotes(source, escapeescapes=0):
   "Returns the same string, with double quotes escaped with backslash"
@@ -201,6 +202,43 @@ def escapesinglequotes(source):
   "Returns the same string, with single quotes doubled"
   return source.replace("'","''")
 
+def htmlentityencode(source):
+  """encodes source using HTML entities e.g. © -> &copy;"""
+  output = ""
+  for char in source:
+    charnum = ord(char)
+    if charnum in htmlentitydefs.codepoint2name:
+      output += "&%s;" % htmlentitydefs.codepoint2name[charnum]
+    else:
+      output += str(char)
+  return output
+
+def htmlentitydecode(source):
+  """decodes source using HTML entities e.g. &copy; -> ©"""
+  output = u""
+  inentity = False
+  for char in source:
+    if char == "&":
+       inentity = True
+       possibleentity = ""
+       continue
+    if inentity:
+      if char == ";":
+        if len(possibleentity) > 0 and possibleentity in htmlentitydefs.name2codepoint:
+          output += unichr(htmlentitydefs.name2codepoint[possibleentity])
+          inentity = False
+        else:
+          output += "&" + possibleentity + ";"
+          inentity = False
+      elif char == " ":
+        output += "&" + possibleentity + char
+        inentity = False
+      else:
+        possibleentity += char
+    else:
+      output += char
+  return output
+
 def javapropertiesencode(source):
   """encodes source in the escaped-unicode encoding used by Java .properties files"""
   output = ""
@@ -342,25 +380,25 @@ def eitherquotestr(source):
   else:
     return quotestr(source)
 
-def findend(string,substring):
+def findend(string, substring):
   s = string.find(substring)
-  if s <> -1:
+  if s != -1:
     s += len(substring)
   return s
 
 def rstripeol(string):
   return string.rstrip("\r\n")
 
-def stripcomment(comment,startstring="<!--",endstring="-->"):
+def stripcomment(comment, startstring="<!--", endstring="-->"):
   cstart = comment.find(startstring)
   if cstart == -1:
     cstart = 0
   else:
     cstart += len(startstring)
-  cend = comment.find(endstring,cstart)
+  cend = comment.find(endstring, cstart)
   return comment[cstart:cend].strip()
 
-def unstripcomment(comment,startstring="<!-- ",endstring=" -->\n"):
+def unstripcomment(comment, startstring="<!-- ", endstring=" -->\n"):
   return startstring+comment.strip()+endstring
 
 def encodewithdict(unencoded, encodedict):
@@ -380,11 +418,11 @@ def makeutf8(d):
 
 def testcase():
   x = ' "this" " is " "a" " test!" '
-  print extract(x,'"','"',None)
-  print extract(x,'"','"','!')
-  print extractwithoutquotes(x,'"','"',None)
-  print extractwithoutquotes(x,'"','"','!')
-  print extractwithoutquotes(x,'"','"','!',includeescapes=False)
+  print extract(x, '"', '"', None)
+  print extract(x, '"', '"', '!')
+  print extractwithoutquotes(x, '"', '"', None)
+  print extractwithoutquotes(x, '"', '"', '!')
+  print extractwithoutquotes(x, '"', '"', '!', includeescapes=False)
 
 if __name__ == '__main__':
   testcase()
