@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # 
-# Copyright 2006-2007 Zuza Software Foundation
+# Copyright 2006-2008 Zuza Software Foundation
 # 
 # This file is part of translate.
 #
@@ -26,9 +26,11 @@
 @license: U{GPL <http://www.fsf.org/licensing/licenses/gpl.html>}
 """
 
-import pickle
+try:
+    import cPickle as pickle
+except:
+    import pickle
 from exceptions import NotImplementedError
-from translate.storage.statistics import Statistics
 
 def force_override(method, baseclass):
     """Forces derived classes to override method."""
@@ -91,7 +93,7 @@ class TranslationUnit(object):
         """Sets the target string to the given value."""
 
         self.target = target
-    
+
     def gettargetlen(self):
         """Returns the length of the target string.
         
@@ -106,6 +108,17 @@ class TranslationUnit(object):
             length += sum([len(pluralform) for pluralform in strings[1:]])
         return length
 
+    def getid(self):
+        """A unique identifier for this unit.
+
+        @rtype: string
+        @return: an identifier for this unit that is unique in the store
+
+        Derived classes should override this in a way that guarantees a unique
+        identifier for each unit in the store.
+        """
+        return self.source
+
     def getlocations(self):
         """A list of source code locations.
         
@@ -185,7 +198,7 @@ class TranslationUnit(object):
         
         """
 
-        raise NotImplementedError
+        pass
 
     def geterrors(self):
         """Get all error messages.
@@ -194,7 +207,7 @@ class TranslationUnit(object):
         
         """
 
-        raise NotImplementedError
+        return {}
 
     def markreviewneeded(self, needsreview=True, explanation=None):
         """Marks the unit to indicate whether it needs review.
@@ -204,7 +217,7 @@ class TranslationUnit(object):
         
         """
 
-        raise NotImplementedError
+        pass
 
     def istranslated(self):
         """Indicates whether this unit is translated.
@@ -217,6 +230,14 @@ class TranslationUnit(object):
 
         return bool(self.target) and not self.isfuzzy()
 
+    def istranslatable(self):
+        """Indicates whether this unit can be translated.
+
+        This should be used to distinguish real units for translation from
+        header, obsolete, binary or other blank units.
+        """
+        return True
+
     def isfuzzy(self):
         """Indicates whether this unit is fuzzy."""
 
@@ -267,8 +288,8 @@ class TranslationUnit(object):
         return [self]
 
     def buildfromunit(cls, unit):
-        """Build a native unit from a foreign unit, preserving as much as 
-        possible information."""
+        """Build a native unit from a foreign unit, preserving as much  
+        information as possible."""
 
         if type(unit) == cls and hasattr(unit, "copy") and callable(unit.copy):
             return unit.copy()
@@ -276,13 +297,15 @@ class TranslationUnit(object):
         newunit.target = unit.target
         newunit.markfuzzy(unit.isfuzzy())
         locations = unit.getlocations()
-        if locations: newunit.addlocations(locations)
+        if locations: 
+            newunit.addlocations(locations)
         notes = unit.getnotes()
-        if notes: newunit.addnote(notes)
+        if notes: 
+            newunit.addnote(notes)
         return newunit
     buildfromunit = classmethod(buildfromunit)
 
-class TranslationStore(Statistics):
+class TranslationStore(object):
     """Base class for stores for multiple translation units of type UnitClass."""
 
     UnitClass = TranslationUnit
@@ -389,34 +412,43 @@ class TranslationStore(Statistics):
         return dump
 
     def isempty(self):
-      """Returns True if the object doesn't contain any translation units."""
+        """Returns True if the object doesn't contain any translation units."""
 
-      if len(self.units) == 0:
+        if len(self.units) == 0:
+            return True
+        for unit in self.units:
+            if not (unit.isblank() or unit.isheader()):
+                return False
         return True
-      # Skip the first unit if it is a header.
-      if self.units[0].isheader():
-        units = self.units[1:]
-      else:
-        units = self.units
 
-      for unit in units:
-        if not unit.isblank():
-          return False
-      return True
+    def _assignname(self):
+        """Tries to work out what the name of the filesystem file is and 
+        assigns it to .filename."""
+        fileobj = getattr(self, "fileobj", None)
+        if fileobj:
+            filename = getattr(fileobj, "name", getattr(fileobj, "filename", None))
+            if filename:
+                self.filename = filename
 
     def parsestring(cls, storestring):
         """Converts the string representation back to an object."""
-
-        return pickle.loads(storestring)
+        newstore = cls()
+        if storestring:
+            newstore.parse(storestring)
+        return newstore
     parsestring = classmethod(parsestring)
 
+    def parse(self, data):
+        """parser to process the given source string"""
+        self.units = pickle.loads(data).units
+
     def savefile(self, storefile):
         """Writes the string representation to the given file (or filename)."""
-
-        storestring = str(self)
         if isinstance(storefile, basestring):
             storefile = open(storefile, "w")
         self.fileobj = storefile
+        self._assignname()
+        storestring = str(self)
         storefile.write(storestring)
         storefile.close()
 
@@ -443,12 +475,13 @@ class TranslationStore(Statistics):
         mode = getattr(storefile, "mode", "r")
         #For some reason GzipFile returns 1, so we have to test for that here
         if mode == 1 or "r" in mode:
-          storestring = storefile.read()
-          storefile.close()
+            storestring = storefile.read()
+            storefile.close()
         else:
-          storestring = ""
+            storestring = ""
         newstore = cls.parsestring(storestring)
         newstore.fileobj = storefile
+        newstore._assignname()
         return newstore
     parsefile = classmethod(parsefile)
 
