@@ -21,53 +21,111 @@
 
 """factory methods to build real storage objects that conform to base.py"""
 
-from translate.storage import base
-from translate.storage import po
-from translate.storage import csvl10n
-from translate.storage import xliff
-from translate.storage import poxliff
-from translate.storage import tmx
-from translate.storage import tbx
-
 import os
 from gzip import GzipFile
-from bz2 import BZ2File
+try:
+    # bz2 is not available on python 2.3
+    from bz2 import BZ2File
+except ImportError:
+    BZ2File = None
+import sys
+
+from translate.storage import base
+from translate.storage import csvl10n
+from translate.storage import mo
+from translate.storage import po
+from translate.storage import qm
+from translate.storage import wordfast
+#Let's try to import the XML formats carefully. They might fail if the user
+#doesn't have lxml installed. Let's try to continue gracefully, but print an 
+#informative warning.
+try:
+    #Although poxliff is unused in this module, it is referenced in test_factory
+    from translate.storage import poxliff
+    from translate.storage import tbx
+    from translate.storage import tmx
+    from translate.storage import xliff
+    support_xml = True
+except ImportError, e:
+    print >> sys.stderr, str(e)
+    support_xml = False
+
 
 #TODO: Monolingual formats (with template?)
 
-classes = {"po": po.pofile, "pot": po.pofile, "csv": csvl10n.csvfile, 
-            "xliff": xliff.xlifffile, "xlf": xliff.xlifffile, 
-            "tmx": tmx.tmxfile, "tbx": tbx.tbxfile}
+classes = {
+           "csv": csvl10n.csvfile, 
+           "po": po.pofile, "pot": po.pofile, 
+           "mo": mo.mofile, "gmo": mo.mofile, 
+           "qm": qm.qmfile, 
+           "_wftm": wordfast.WordfastTMFile,
+          }
+"""Dictionary of file extensions and their associated class.  
+
+_ext is a pseudo extension, that is their is no real extension by that name."""
+
+if support_xml:
+    classes.update({
+           "tbx": tbx.tbxfile,
+           "tmx": tmx.tmxfile, 
+           "xliff": xliff.xlifffile, "xlf": xliff.xlifffile, 
+    })
 
 decompressclass = {
     'gz': GzipFile,
-    'bz2': BZ2File,
 }
+if BZ2File:
+    decompressclass['bz2'] = BZ2File
 
-def guessextention(storefile):
+def _examine_txt(storefile):
+    """Determine the true filetype for a .txt file"""
+    if isinstance(storefile, basestring) and os.path.exists(storefile):
+        storefile = open(storefile)
+    try:
+        start = storefile.read(600).strip()
+    except AttributeError:
+        raise ValueError("Need to read object to determine type")
+    # Some encoding magic for Wordfast
+    if wordfast.TAB_UTF16 in start.split("\n")[0]:
+        encoding = 'utf-16'
+    else:
+        encoding = 'iso-8859-1'
+    start = start.decode(encoding).encode('utf-8')
+    if '%Wordfast TM' in start:
+        pseudo_extension = '_wftm'
+    else:
+        raise ValueError("Failed to guess file type.")
+    storefile.seek(0)
+    return pseudo_extension
+
+hiddenclasses = {"txt": _examine_txt}
+
+def _guessextention(storefile):
     """Guesses the type of a file object by looking at the first few characters.
     The return value is a file extention ."""
-    start = storefile.read(200).strip()
+    start = storefile.read(300).strip()
     if '<xliff ' in start:
         extention = 'xlf'
     elif 'msgid "' in start:
         extention = 'po'
+    elif '%Wordfast TM' in start:
+        extention = 'txt'
     else:
         raise ValueError("Failed to guess file type.")
     storefile.seek(0)
     return extention
 
-def getdummyname(storefile):
+def _getdummyname(storefile):
     """Provides a dummy name for a file object without a name attribute, by guessing the file type."""
-    return 'dummy.' + guessextention(storefile)
+    return 'dummy.' + _guessextention(storefile)
 
-def getname(storefile):
+def _getname(storefile):
     """returns the filename"""
     if storefile is None:
         raise ValueError("This method cannot magically produce a filename when given None as input.")
     if not isinstance(storefile, basestring):
         if not hasattr(storefile, "name"):
-            storefilename = getdummyname(storefile)
+            storefilename = _getdummyname(storefile)
         else:
             storefilename = storefile.name
     else:
@@ -77,14 +135,22 @@ def getname(storefile):
 def getclass(storefile, ignore=None):
     """Factory that returns the applicable class for the type of file presented.
     Specify ignore to ignore some part at the back of the name (like .gz). """
-    storefilename = getname(storefile)
+    storefilename = _getname(storefile)
     if ignore and storefilename.endswith(ignore):
-        storefilename = storefile[:-len(ignore)]
+        storefilename = storefilename[:-len(ignore)]
     root, ext = os.path.splitext(storefilename)
     ext = ext[len(os.path.extsep):].lower()
+    decomp = None
     if ext in decompressclass:
+        decomp = ext
         root, ext = os.path.splitext(root)
         ext = ext[len(os.path.extsep):].lower()
+    if ext in hiddenclasses:
+        guesserfn = hiddenclasses[ext]
+        if decomp:
+            ext = guesserfn(decompressclass[decomp](storefile))
+        else:
+            ext = guesserfn(storefile)
     try:
         storeclass = classes[ext]
     except KeyError:
@@ -106,8 +172,8 @@ def getobject(storefile, ignore=None):
         if os.path.isdir(storefile) or storefile.endswith(os.path.sep):
             from translate.storage import directory
             return directory.Directory(storefile)
-    storefilename = getname(storefile)
-    storeclass = getclass(storefilename, ignore)
+    storefilename = _getname(storefile)
+    storeclass = getclass(storefile, ignore)
     if os.path.exists(storefilename) or not getattr(storefile, "closed", True):
         name, ext = os.path.splitext(storefilename)
         ext = ext[len(os.path.extsep):].lower()
