@@ -58,10 +58,10 @@ class TestTranslationUnit:
         assert unit1 == unit1
         assert unit1 == unit2
         assert unit1 != unit4
-        unit1.settarget("Stressed Ting")
-        unit2.settarget("Stressed Ting")
-        unit5.settarget("Stressed Bling")
-        unit6.settarget("Stressed Ting")
+        unit1.target = "Stressed Ting"
+        unit2.target = "Stressed Ting"
+        unit5.target = "Stressed Bling"
+        unit6.target = "Stressed Ting"
         assert unit1 == unit2
         assert unit1 != unit3
         assert unit4 != unit5
@@ -70,11 +70,11 @@ class TestTranslationUnit:
     def test_target(self):
         unit = self.unit
         assert not unit.target
-        unit.settarget("Stressed Ting")
+        unit.target = "Stressed Ting"
         assert unit.target == "Stressed Ting"
-        unit.settarget("Stressed Bling")
+        unit.target = "Stressed Bling"
         assert unit.target == "Stressed Bling"
-        unit.settarget("")
+        unit.target = ""
         assert unit.target == ""
 
     def test_escapes(self):
@@ -82,7 +82,7 @@ class TestTranslationUnit:
         escaping roundtrip."""
         unit = self.unit
         specials = ['Fish & chips', 'five < six', 'six > five', 'five &lt; six',
-                    'Use &nbsp;', 'Use &amp;nbsp;', 'Use &amp;amp;nbsp;'
+                    'Use &nbsp;', 'Use &amp;nbsp;', 'Use &amp;amp;nbsp;',
                     'A "solution"', "skop 'n bal", '"""', "'''", u'µ',
                     '\n', '\t', '\r', '\r\n', '\\r', '\\', '\\\r'] 
         for special in specials:
@@ -105,34 +105,6 @@ class TestTranslationUnit:
             print "special:", repr(special) + '|'
             assert unit.source == special
 
-    def test_markreview(self):
-        """Tests if we can mark the unit to need review."""
-        unit = self.unit
-        # We have to explicitly set the target to nothing, otherwise xliff
-        # tests will fail.
-        # Can we make it default behavior for the UnitClass?
-        unit.target = ""
-
-        unit.addnote("Test note 1", origin="translator")
-        unit.addnote("Test note 2", origin="translator")
-        original_notes = unit.getnotes(origin="translator")
-
-        # The base class methods won't be implemented:
-        if self.__module__.endswith('test_base'):
-            assert test.raises(NotImplementedError, unit.markreviewneeded) 
-            return
-
-        assert not unit.isreview()
-        unit.markreviewneeded()
-        assert unit.isreview()
-        unit.markreviewneeded(False)
-        assert not unit.isreview()
-        assert unit.getnotes(origin="translator") == original_notes
-        unit.markreviewneeded(explanation="Double check spelling.")
-        assert unit.isreview()
-        notes = unit.getnotes(origin="translator")
-        assert notes.count("Double check spelling.") == 1
-
     def test_note_sanity(self):
         """Tests that all subclasses of the base behaves consistently with regards to notes."""
         unit = self.unit
@@ -154,26 +126,6 @@ class TestTranslationUnit:
         actual_notes = unit.getnotes()
         assert actual_notes == expected_notes
 
-    def test_errors(self):
-        """Tests that we can add and retrieve error messages for a unit."""
-        unit = self.unit
-
-        # The base class methods won't be implemented:
-        if self.__module__.endswith('test_base'):
-            assert test.raises(NotImplementedError, unit.markreviewneeded) 
-            return
-
-        assert len(unit.geterrors()) == 0
-        unit.adderror(errorname='test1', errortext='Test error message 1.')
-        unit.adderror(errorname='test2', errortext='Test error message 2.')
-        unit.adderror(errorname='test3', errortext='Test error message 3.')
-        assert len(unit.geterrors()) == 3
-        assert unit.geterrors()['test1'] == 'Test error message 1.'
-        assert unit.geterrors()['test2'] == 'Test error message 2.'
-        assert unit.geterrors()['test3'] == 'Test error message 3.'
-        unit.adderror(errorname='test1', errortext='New error 1.')
-        assert unit.geterrors()['test1'] == 'New error 1.'
-
 class TestTranslationStore:
     """Tests a TranslationStore.
     Derived classes can reuse these tests by pointing StoreClass to a derived Store"""
@@ -249,7 +201,9 @@ class TestTranslationStore:
         """Tests converting to a string and parsing the resulting string"""
         store = self.StoreClass()
         unit1 = store.addsourceunit("Test String")
-        unit2 = store.addsourceunit("Blessed String")
+        unit1.target = "Test String"
+        unit2 = store.addsourceunit("Test String 2")
+        unit2.target = "Test String 2"
         newstore = self.reparse(store)
         self.check_equality(store, newstore)
 
@@ -257,7 +211,9 @@ class TestTranslationStore:
         """Tests saving to and loading from files"""
         store = self.StoreClass()
         unit1 = store.addsourceunit("Test String")
-        unit2 = store.addsourceunit("Blessed String")
+        unit1.target = "Test String"
+        unit2 = store.addsourceunit("Test String 2")
+        unit2.target = "Test String 2"
         store.savefile(self.filename)
         newstore = self.StoreClass.parsefile(self.filename)
         self.check_equality(store, newstore)
@@ -266,6 +222,9 @@ class TestTranslationStore:
         """Tests that we can save directly back to the original file."""
         store = self.StoreClass()
         unit1 = store.addsourceunit("Test String")
+        unit1.target = "Test String"
+        unit2 = store.addsourceunit("Test String 2")
+        unit2.target = "Test String 2"
         store.savefile(self.filename)
         store.save()
         newstore = self.StoreClass.parsefile(self.filename)
@@ -290,38 +249,3 @@ class TestTranslationStore:
         assert answer == u"Beziér-kurwe"
         #Just test that __str__ doesn't raise exception:
         src = str(store)
-
-    def test_store_stats(self):
-        store = self.StoreClass()
-        unit1 = store.addsourceunit("Test source")
-        store.units[0].markfuzzy(False)
-        assert store.source_wordcount() == 2
-        unit2 = store.addsourceunit("Test source 2")
-        store.units[1].markfuzzy(False)
-        store.classifyunits()
-        assert store.source_wordcount() == 5
-        # If the source has also been changed, assume it's a monolingual file.
-        if not unit1.source == unit1.target:
-            assert store.translated_unitcount() == 0
-            assert store.untranslated_unitcount() == 2
-            assert store.translated_wordcount() == 0
-            assert store.untranslated_wordcount() == 5
-        unit1.settarget("Toets bron teks")
-        store.classifyunits()
-        # If the source has also been changed, assume it's a monolingual file.
-        if not unit1.source == unit1.target:
-            assert store.translated_unitcount() == 1
-            assert store.untranslated_unitcount() == 1
-            assert store.translated_wordcount() == 2
-            assert store.untranslated_wordcount() == 3
-
-        assert not store.fuzzy_units()
-        unit1.markfuzzy(True)
-        if unit1.isfuzzy():
-            store.classifyunits()
-            assert store.fuzzy_unitcount() == 1
-
-        store = self.StoreClass()
-        unit1 = store.addsourceunit(u"ភាសា​ខ្មែរ")
-        unit2 = store.addsourceunit(u"សាលារៀន")
-        assert store.source_wordcount() == 3
