@@ -3,20 +3,10 @@
 from translate.storage import tmx
 from translate.storage import test_base
 from translate.misc import wStringIO
-from py import test
 
 class TestTMXUnit(test_base.TestTranslationUnit):
     UnitClass = tmx.tmxunit
 
-    def test_markreview(self):
-        assert test.raises(NotImplementedError, self.unit.markreviewneeded)
-
-    def test_errors(self):
-        """Assert the fact that geterrors() and adderror() is not (yet) implemented.
-        This test needs to be removed when these methods get implemented."""
-        assert test.raises(NotImplementedError, self.unit.geterrors)
-        assert test.raises(NotImplementedError, self.unit.adderror, 'testname', 'Test error')
-
 class TestTMXUnitFromParsedString(TestTMXUnit):
     tmxsource = '''<?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE tmx
@@ -50,7 +40,7 @@ class TestTMXfile(test_base.TestTranslationStore):
         return tmxfile
 
     def test_translate(self):
-        tmxfile= tmx.tmxfile()
+        tmxfile = tmx.tmxfile()
         assert tmxfile.translate("Anything") is None
         tmxfile.addtranslation("A string of characters", "en", "'n String karakters", "af")
         assert tmxfile.translate("A string of characters") == "'n String karakters"
