@@ -3,13 +3,10 @@
 from translate.storage import txt
 from translate.storage import test_monolingual
 from translate.misc import wStringIO
-from py import test
 
 class TestTxtUnit(test_monolingual.TestMonolingualUnit):
     UnitClass = txt.TxtUnit
 
-    def test_markreview(self):
-        assert test.raises(NotImplementedError, self.unit.markreviewneeded)
 
 class TestTxtFile(test_monolingual.TestMonolingualStore):
     StoreClass = txt.TxtFile
