@@ -2,10 +2,6 @@
 
 from translate.storage import xliff
 from translate.storage import test_base
-from translate.misc import wStringIO
-from translate.misc.multistring import multistring
-
-from py import test
 
 class TestXLIFFUnit(test_base.TestTranslationUnit):
     UnitClass = xliff.xliffunit
@@ -15,8 +11,55 @@ class TestXLIFFUnit(test_base.TestTranslationUnit):
         from test_base.py"""
         assert self.unit.isfuzzy()
 
+    def test_markreview(self):
+        """Tests if we can mark the unit to need review."""
+        unit = self.unit
+        # We have to explicitly set the target to nothing, otherwise xliff
+        # tests will fail.
+        # Can we make it default behavior for the UnitClass?
+        unit.target = ""
+
+        unit.addnote("Test note 1", origin="translator")
+        unit.addnote("Test note 2", origin="translator")
+        original_notes = unit.getnotes(origin="translator")
+
+        assert not unit.isreview()
+        unit.markreviewneeded()
+        assert unit.isreview()
+        unit.markreviewneeded(False)
+        assert not unit.isreview()
+        assert unit.getnotes(origin="translator") == original_notes
+        unit.markreviewneeded(explanation="Double check spelling.")
+        assert unit.isreview()
+        notes = unit.getnotes(origin="translator")
+        assert notes.count("Double check spelling.") == 1
+
+    def test_errors(self):
+        """Tests that we can add and retrieve error messages for a unit."""
+        unit = self.unit
+
+        assert len(unit.geterrors()) == 0
+        unit.adderror(errorname='test1', errortext='Test error message 1.')
+        unit.adderror(errorname='test2', errortext='Test error message 2.')
+        unit.adderror(errorname='test3', errortext='Test error message 3.')
+        assert len(unit.geterrors()) == 3
+        assert unit.geterrors()['test1'] == 'Test error message 1.'
+        assert unit.geterrors()['test2'] == 'Test error message 2.'
+        assert unit.geterrors()['test3'] == 'Test error message 3.'
+        unit.adderror(errorname='test1', errortext='New error 1.')
+        assert unit.geterrors()['test1'] == 'New error 1.'
+
 class TestXLIFFfile(test_base.TestTranslationStore):
     StoreClass = xliff.xlifffile
+    skeleton = '''<?xml version="1.0" encoding="utf-8"?>
+<xliff version="1.1" xmlns="urn:oasis:names:tc:xliff:document:1.1">
+        <file original="doc.txt" source-language="en-US">
+                <body>
+                        %s
+                </body>
+        </file>
+</xliff>'''
+
     def test_basic(self):
         xlifffile = xliff.xlifffile()
         assert xlifffile.units == []
@@ -65,26 +108,26 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         unit = xlifffile.addsourceunit("Concept")
         unit.addnote("Please buy bread")
         assert unit.getnotes() == "Please buy bread"
-        notenodes = unit.xmlelement.getElementsByTagName("note")
+        notenodes = unit.xmlelement.findall(".//%s" % unit.namespaced("note"))
         assert len(notenodes) == 1
 
         unit.addnote("Please buy milk", origin="Mom")
-        notenodes = unit.xmlelement.getElementsByTagName("note")
+        notenodes = unit.xmlelement.findall(".//%s" % unit.namespaced("note"))
         assert len(notenodes) == 2
-        assert not notenodes[0].hasAttribute("from")
-        assert notenodes[1].getAttribute("from") == "Mom"
+        assert not "from" in notenodes[0].attrib
+        assert notenodes[1].get("from") == "Mom"
         assert unit.getnotes(origin="Mom") == "Please buy milk"
 
         unit.addnote("Don't forget the beer", origin="Dad")
-        notenodes = unit.xmlelement.getElementsByTagName("note")
+        notenodes = unit.xmlelement.findall(".//%s" % unit.namespaced("note"))
         assert len(notenodes) == 3
-        assert notenodes[1].getAttribute("from") == "Mom"
-        assert notenodes[2].getAttribute("from") == "Dad"
+        assert notenodes[1].get("from") == "Mom"
+        assert notenodes[2].get("from") == "Dad"
         assert unit.getnotes(origin="Dad") == "Don't forget the beer"
 
         assert not unit.getnotes(origin="Bob") == "Please buy bread\nPlease buy milk\nDon't forget the beer"
-        assert not notenodes[2].getAttribute("from") == "Mom"
-        assert not notenodes[0].hasAttribute("from")
+        assert not notenodes[2].get("from") == "Mom"
+        assert not "from" in notenodes[0].attrib
         assert unit.getnotes() == "Please buy bread\nPlease buy milk\nDon't forget the beer"
         assert unit.correctorigin(notenodes[2], "ad") == True
         assert unit.correctorigin(notenodes[2], "om") == False
@@ -136,23 +179,32 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         assert unit.target is None
         print unit
         unit.markfuzzy(True)
-        assert unit.xmlelement.getAttribute("approved") == "no"
+        assert 'approved="no"' in str(unit)
         #assert unit.isfuzzy()
 
     def test_parsing(self):
-        xlfsource = '''<?xml version="1.0" encoding="utf-8"?>
-<xliff version="1.1" xmlns="urn:oasis:names:tc:xliff:document:1.1">
-        <file datatype="po" original="doc.txt" source-language="en-US">
-                <body>
-                        <trans-unit id="2" xml:space="preserve">
-                                <source>&amp;Applications</source>
-                                <target/>
-                        </trans-unit>
-                </body>
-        </file>
-</xliff>'''
+        xlfsource = self.skeleton \
+          % '''<trans-unit id="1" xml:space="preserve">
+                   <source>File</source>
+                   <target/>
+               </trans-unit>'''
         xlifffile = xliff.xlifffile.parsestring(xlfsource)
-        assert len(xlifffile.units) == 1
-        print xlifffile.units[0].source
-        assert xlifffile.units[0].source == "&Applications"
+        assert xlifffile.units[0].istranslatable()
+
+        xlfsource = self.skeleton \
+          % '''<trans-unit id="1" xml:space="preserve" translate="no">
+                   <source>File</source>
+                   <target/>
+               </trans-unit>'''
+        xlifffile = xliff.xlifffile.parsestring(xlfsource)
+        assert not xlifffile.units[0].istranslatable()
+
+        xlfsource = self.skeleton \
+          % '''<trans-unit id="1" xml:space="preserve" translate="yes">
+                   <source>File</source>
+                   <target/>
+               </trans-unit>'''
+        xlifffile = xliff.xlifffile.parsestring(xlfsource)
+        assert xlifffile.units[0].istranslatable()
+
 
