@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright 2005-2006 Zuza Software Foundation
+# Copyright 2005-2007 Zuza Software Foundation
 # 
 # This file is part of translate.
 #
@@ -27,6 +27,7 @@ The official recommendation is to use the extention .xlf for XLIFF files.
 
 from translate.storage import base
 from translate.storage import lisa
+from lxml import etree
 
 # TODO: handle translation types
 
@@ -36,6 +37,7 @@ class xliffunit(lisa.LISAunit):
     rootNode = "trans-unit"
     languageNode = "source"
     textNode = ""
+    namespace = 'urn:oasis:names:tc:xliff:document:1.1'
 
     #TODO: id and all the trans-unit level stuff
 
@@ -46,20 +48,18 @@ class xliffunit(lisa.LISAunit):
         # with parameter. Alternatively, we can use lang, if supplied, since an xliff 
         #file has to conform to the bilingual nature promised by the header.
         assert purpose
-        langset = self.document.createElement(purpose)
+        langset = etree.Element(self.namespaced(purpose))
         #TODO: check language
-#        langset.setAttribute("xml:lang", lang)
+#        lisa.setXMLlang(langset, lang)
 
-#        message = self.document.createTextNode(text)
-#        langset.appendChild(message)
-        self.createPHnodes(langset, text)
+#        self.createPHnodes(langset, text)
+        langset.text = text
         return langset
     
     def getlanguageNodes(self):
         """We override this to get source and target nodes."""
-
-        sources = self.xmlelement.getElementsByTagName(self.languageNode)
-        targets = self.xmlelement.getElementsByTagName("target")
+        sources = self.xmlelement.findall('.//%s' % self.namespaced(self.languageNode))
+        targets = self.xmlelement.findall('.//%s' % self.namespaced('target'))
         sourcesl = len(sources)
         targetsl = len(targets)
         nodes = []
@@ -80,36 +80,32 @@ class xliffunit(lisa.LISAunit):
         # the source tag is needed to inject fuzzy matches from a TM.
         if isinstance(txt, str):
             txt = txt.decode("utf-8")
-        alttarget = self.document.createElement("target")
-        alttarget.appendChild(self.document.createTextNode(txt))
-        alttrans = self.document.createElement("alt-trans")
-        alttrans.appendChild(alttarget)
+        alttrans = etree.SubElement(self.xmlelement, self.namespaced("alt-trans"))
+        alttarget = etree.SubElement(alttrans, self.namespaced("target"))
+        alttarget.text = txt
         if origin:
-            alttrans.setAttribute("origin", origin)
+            alttrans.set("origin", origin)
         if lang:
-            alttrans.setAttribute("xml:lang", lang)
-        self.xmlelement.appendChild(alttrans)
+            lisa.setXMLlang(alttrans, lang)
 
     def getalttrans(self, origin=None):
         """Returns <alt-trans> for the given origin as a list of units. No 
         origin means all alternatives."""
-        nodes = self.xmlelement.getElementsByTagName("alt-trans")
         translist = []
-        for i in range(len(nodes)):
-            if self.correctorigin(nodes[i], origin):
+        for node in self.xmlelement.findall(".//%s" % self.namespaced("alt-trans")):
+            if self.correctorigin(node, origin):
                 # We build some mini units that keep the xmlelement. This 
                 # makes it easier to delete it if it is passed back to us.
                 newunit = base.TranslationUnit(self.source)
-                node = nodes[i]
 
                 # the source tag is optional
-                sourcelist = node.getElementsByTagName("source")
-                if sourcelist:
-                    newunit.source = lisa.getText(sourcelist[0])
+                sourcenode = node.find(".//%s" % self.namespaced("source"))
+                if not sourcenode is None:
+                    newunit.source = lisa.getText(sourcenode)
 
                 # must have one or more targets
-                targetlist = node.getElementsByTagName("target")
-                newunit.target = lisa.getText(targetlist[0])
+                targetnode = node.find(".//%s" % self.namespaced("target"))
+                newunit.target = lisa.getText(targetnode)
                 #TODO: support multiple targets better
                 #TODO: support notes in alt-trans
                 newunit.xmlelement = node
@@ -119,21 +115,23 @@ class xliffunit(lisa.LISAunit):
 
     def delalttrans(self, alternative):
         """Removes the supplied alternative from the list of alt-trans tags"""
-        self.xmlelement.removeChild(alternative.xmlelement)
+        self.xmlelement.remove(alternative.xmlelement)
 
     def addnote(self, text, origin=None):
         """Add a note specifically in a "note" tag"""
         if isinstance(text, str):
             text = text.decode("utf-8")
-        note = self.document.createElement("note")
-        note.appendChild(self.document.createTextNode(text.strip()))
+        note = etree.SubElement(self.xmlelement, self.namespaced("note"))
+        note.text = text.strip()
         if origin:
-            note.setAttribute("from", origin)
-        self.xmlelement.appendChild(note)        
+            note.set("from", origin)
 
     def getnotelist(self, origin=None):
         """Private method that returns the text from notes matching 'origin' or all notes."""
-        notenodes = self.xmlelement.getElementsByTagName("note")
+        notenodes = self.xmlelement.findall(".//%s" % self.namespaced("note"))
+        # TODO: consider using xpath to construct initial_list directly
+        # or to simply get the correct text from the outset (just remember to
+        # check for duplication.
         initial_list = [lisa.getText(note) for note in notenodes if self.correctorigin(note, origin)]
 
         # Remove duplicate entries from list:
@@ -143,22 +141,24 @@ class xliffunit(lisa.LISAunit):
         return notelist 
 
     def getnotes(self, origin=None):
-        return '\n'.join(self.getnotelist(origin=origin)) 
+        return '\n'.join(self.getnotelist(origin=origin))
 
     def removenotes(self):
         """Remove all the translator notes."""
-        notes = self.xmlelement.getElementsByTagName("note")
+        notes = self.xmlelement.findall(".//%s" % self.namespaced("note"))
         for note in notes:
             if self.correctorigin(note, origin="translator"):
-                self.xmlelement.removeChild(note)
+                self.xmlelement.remove(note)
 
     def adderror(self, errorname, errortext):
         """Adds an error message to this unit."""
+        #TODO: consider factoring out: some duplication between XLIFF and TMX
         text = errorname + ': ' + errortext
         self.addnote(text, origin="pofilter")
 
     def geterrors(self):
         """Get all error messages."""
+        #TODO: consider factoring out: some duplication between XLIFF and TMX
         notelist = self.getnotelist(origin="pofilter")
         errordict = {}
         for note in notelist:
@@ -167,46 +167,53 @@ class xliffunit(lisa.LISAunit):
         return errordict
 
     def isapproved(self):
-        """States whether this unit is approved"""
-        return self.xmlelement.getAttribute("approved") == "yes"
+        """States whether this unit is approved."""
+        return self.xmlelement.get("approved") == "yes"
+
+    def markapproved(self, value=True):
+        """Mark this unit as approved."""
+        if value:
+            self.xmlelement.set("approved", "yes")
+        else:
+            self.xmlelement.set("approved", "no")
 
     def isreview(self):
         """States whether this unit needs to be reviewed"""
         targetnode = self.getlanguageNode(lang=None, index=1)
         return not targetnode is None and \
-                "needs-review" in targetnode.getAttribute("state")
+                "needs-review" in targetnode.get("state", "")
 
     def markreviewneeded(self, needsreview=True, explanation=None):
         """Marks the unit to indicate whether it needs review. Adds an optional explanation as a note."""
         targetnode = self.getlanguageNode(lang=None, index=1)
-        if targetnode:
+        if not targetnode is None:
             if needsreview:
-                targetnode.setAttribute("state", "needs-review-translation")
+                targetnode.set("state", "needs-review-translation")
                 if explanation:
                     self.addnote(explanation, origin="translator")
             else:
-                targetnode.removeAttribute("state")
+                del targetnode.attrib["state"]
 
     def isfuzzy(self):
 #        targetnode = self.getlanguageNode(lang=None, index=1)
 #        return not targetnode is None and \
-#                (targetnode.getAttribute("state-qualifier") == "fuzzy-match" or \
-#                targetnode.getAttribute("state") == "needs-review-translation")
+#                (targetnode.get("state-qualifier") == "fuzzy-match" or \
+#                targetnode.get("state") == "needs-review-translation")
         return not self.isapproved()
                 
     def markfuzzy(self, value=True):
         if value:
-            self.xmlelement.setAttribute("approved", "no")
+            self.markapproved(False)
         else:
-            self.xmlelement.setAttribute("approved", "yes")
+            self.markapproved(True)
         targetnode = self.getlanguageNode(lang=None, index=1)
-        if targetnode:
+        if not targetnode is None:
             if value:
-                targetnode.setAttribute("state", "needs-review-translation")
+                targetnode.set("state", "needs-review-translation")
             else:
                 for attribute in ["state", "state-qualifier"]:
-                    if targetnode.hasAttribute(attribute):
-                        targetnode.removeAttribute(attribute)
+                    if attribute in targetnode.attrib:
+                        del targetnode.attrib[attribute]
 
     def settarget(self, text, lang='xx', append=False):
         """Sets the target string to the given value."""
@@ -219,22 +226,31 @@ class xliffunit(lisa.LISAunit):
 #    def istranslated(self):
 #        targetnode = self.getlanguageNode(lang=None, index=1)
 #        return not targetnode is None and \
-#                (targetnode.getAttribute("state") == "translated")
+#                (targetnode.get("state") == "translated")
+
+    def istranslatable(self):
+        value = self.xmlelement.get("translate")
+        if value and value.lower() == 'no':
+            return False
+        return True
 
     def marktranslated(self):
         targetnode = self.getlanguageNode(lang=None, index=1)
         if not targetnode:
             return
-        if self.isfuzzy() and targetnode.hasAttribute("state-qualifier"):
+        if self.isfuzzy() and "state-qualifier" in targetnode.attrib:
             #TODO: consider
-            targetnode.removeAttribute("state-qualifier")
-        targetnode.setAttribute("state", "translated")
+            del targetnode.attrib["state-qualifier"]
+        targetnode.set("state", "translated")
 
     def setid(self, id):
-        self.xmlelement.setAttribute("id", id)
+        self.xmlelement.set("id", id)
 
     def getid(self):
-        return self.xmlelement.getAttribute("id")
+        return self.xmlelement.get("id") or ""
+
+    def addlocation(self, location):
+        self.setid(location)
 
     def getlocations(self):
         return [self.getid()]
@@ -243,36 +259,33 @@ class xliffunit(lisa.LISAunit):
         """Add the context group to the trans-unit with contexts a list with
         (type, text) tuples describing each context."""
         assert contexts
-        group = self.document.createElement("context-group")
-        group.setAttribute("name", name)
+        group = etree.SubElement(self.xmlelement, self.namespaced("context-group"))
+        group.set("name", name)
         if purpose:
-            group.setAttribute("purpose", purpose)
+            group.set("purpose", purpose)
         for type, text in contexts:
             if isinstance(text, str):
                 text = text.decode("utf-8")
-            context = self.document.createElement("context")
-            context.setAttribute("context-type", type)
-            nodetext = self.document.createTextNode(text)
-            context.appendChild(nodetext)
-            group.appendChild(context)
-        self.xmlelement.appendChild(group)
+            context = etree.SubElement(group, self.namespaced("context"))
+            context.text = text
+            context.set("context-type", type)
 
     def getcontextgroups(self, name):
         """Returns the contexts in the context groups with the specified name"""
         groups = []
-        grouptags = self.xmlelement.getElementsByTagName("context-group")
+        grouptags = self.xmlelement.findall(".//%s" % self.namespaced("context-group"))
         for group in grouptags:
-            if group.getAttribute("name") == name:
-                contexts = group.getElementsByTagName("context")
+            if group.get("name") == name:
+                contexts = group.findall(".//%s" % self.namespaced("context"))
                 pairs = []
                 for context in contexts:
-                    pairs.append((context.getAttribute("context-type"), lisa.getText(context)))
+                    pairs.append((context.get("context-type"), lisa.getText(context)))
                 groups.append(pairs) #not extend
         return groups
         
     def getrestype(self):
         """returns the restype attribute in the trans-unit tag"""
-        return self.xmlelement.getAttribute("restype")
+        return self.xmlelement.get("restype")
 
     def merge(self, otherunit, overwrite=False, comments=True):
         #TODO: consider other attributes like "approved"
@@ -286,9 +299,9 @@ class xliffunit(lisa.LISAunit):
         """Check against node tag's origin (e.g note or alt-trans)"""
         if origin == None:
             return True
-        elif origin in node.getAttribute("from"):
+        elif origin in node.get("from", ""):
             return True
-        elif origin in node.getAttribute("origin"):
+        elif origin in node.get("origin", ""):
             return True
         else:
             return False
@@ -300,31 +313,33 @@ class xlifffile(lisa.LISAfile):
     bodyNode = "body"
     XMLskeleton = '''<?xml version="1.0" ?>
 <xliff version='1.1' xmlns='urn:oasis:names:tc:xliff:document:1.1'>
- <file original='NoName' source-language='en' datatype='plaintext'>
-  <body>
-  </body>
- </file>
+<file original='NoName' source-language='en' datatype='plaintext'>
+<body>
+</body>
+</file>
 </xliff>'''
+    namespace = 'urn:oasis:names:tc:xliff:document:1.1'
 
-    def __init__(self,*args,**kwargs):
-        lisa.LISAfile.__init__(self,*args,**kwargs)
+    def __init__(self, *args, **kwargs):
+        lisa.LISAfile.__init__(self, *args, **kwargs)
         self._filename = "NoName"
         self._messagenum = 0
 
         # Allow the inputfile to override defaults for source and target language.
-        filenode = self.document.getElementsByTagName('file')[0]
-        sourcelanguage = filenode.getAttribute('source-language')
+        filenode = self.document.find('.//%s' % self.namespaced('file'))
+        sourcelanguage = filenode.get('source-language')
         if sourcelanguage:
             self.setsourcelanguage(sourcelanguage)
-        targetlanguage = filenode.getAttribute('target-language')
+        targetlanguage = filenode.get('target-language')
         if targetlanguage:
             self.settargetlanguage(targetlanguage)
 
     def addheader(self):
         """Initialise the file header."""
-        self.document.getElementsByTagName("file")[0].setAttribute("source-language", self.sourcelanguage)
+        filenode = self.document.find(self.namespaced("file"))
+        filenode.set("source-language", self.sourcelanguage)
         if self.targetlanguage:
-            self.document.getElementsByTagName("file")[0].setAttribute("target-language", self.targetlanguage)
+            filenode.set("target-language", self.targetlanguage)
 
     def createfilenode(self, filename, sourcelanguage=None, targetlanguage=None, datatype='plaintext'):
         """creates a filenode with the given filename. All parameters are needed
@@ -334,31 +349,31 @@ class xlifffile(lisa.LISAfile):
             sourcelanguage = self.sourcelanguage
         if targetlanguage is None:
             targetlanguage = self.targetlanguage
-        filenode = self.document.createElement("file")
-        filenode.setAttribute("original", filename)
-        filenode.setAttribute("source-language", sourcelanguage)
+        filenode = etree.Element(self.namespaced("file"))
+        filenode.set("original", filename)
+        filenode.set("source-language", sourcelanguage)
         if targetlanguage:
-            filenode.setAttribute("target-language", targetlanguage)
-        filenode.setAttribute("datatype", datatype)
-        bodyNode = self.document.createElement(self.bodyNode)
-        filenode.appendChild(bodyNode)
+            filenode.set("target-language", targetlanguage)
+        filenode.set("datatype", datatype)
+        bodyNode = etree.SubElement(filenode, self.namespaced(self.bodyNode))
         return filenode
 
     def getfilename(self, filenode):
         """returns the name of the given file"""
-        return filenode.getAttribute("original")
+        return filenode.get("original")
 
     def getfilenames(self):
         """returns all filenames in this XLIFF file"""
-        filenodes = self.document.getElementsByTagName("file")
+        filenodes = self.document.findall(self.namespaced("file"))
         filenames = [self.getfilename(filenode) for filenode in filenodes]
+        filenames = filter(None, filenames)
         if len(filenames) == 1 and filenames[0] == '':
             filenames = []
         return filenames
 
     def getfilenode(self, filename):
         """finds the filenode with the given name"""
-        filenodes = self.document.getElementsByTagName("file")
+        filenodes = self.document.findall(self.namespaced("file"))
         for filenode in filenodes:
             if self.getfilename(filenode) == filename:
                 return filenode
@@ -369,8 +384,8 @@ class xlifffile(lisa.LISAfile):
         the datatype of the first file is given."""
         if filename:
             node = self.getfilenode(filename)
-            if node:
-                return node.getAttribute("datatype")
+            if not node is None:
+                return node.get("datatype")
         else:
             filenames = self.getfilenames()
             if len(filenames) > 0 and filenames[0] != "NoName":
@@ -380,46 +395,44 @@ class xlifffile(lisa.LISAfile):
     def removedefaultfile(self):
         """We want to remove the default file-tag as soon as possible if we 
         know if still present and empty."""
-        filenodes = self.document.getElementsByTagName("file")
+        filenodes = self.document.findall(self.namespaced("file"))
         if len(filenodes) > 1:
             for filenode in filenodes:
-                if filenode.getAttribute("original") == "NoName" and \
-                        not filenode.getElementsByTagName(self.UnitClass.rootNode):
-                    self.document.documentElement.removeChild(filenode)
+                if filenode.get("original") == "NoName" and \
+                        not filenode.findall(".//%s" % self.namespaced(self.UnitClass.rootNode)):
+                    self.document.getroot().remove(filenode)
                 break
 
     def getheadernode(self, filenode, createifmissing=False):
         """finds the header node for the given filenode"""
         # TODO: Deprecated?
-        headernodes = list(filenode.getElementsByTagName("header"))
-        if headernodes:
-            return headernodes[0]
+        headernode = list(filenode.find(self.namespaced("header")))
+        if not headernode is None:
+            return headernode
         if not createifmissing:
             return None
-        headernode = ourdom.Element("header")
-        filenode.appendChild(headernode)
+        headernode = etree.SubElement(filenode, self.namespaced("header"))
         return headernode
 
     def getbodynode(self, filenode, createifmissing=False):
         """finds the body node for the given filenode"""
-        bodynodes = list(filenode.getElementsByTagName("body"))
-        if bodynodes:
-            return bodynodes[0]
+        bodynode = filenode.find(self.namespaced("body"))
+        if not bodynode is None:
+            return bodynode
         if not createifmissing:
             return None
-        bodynode = self.document.createElement("body")
-        filenode.appendChild(bodynode)
+        bodynode = etree.SubElement(filenode, self.namespaced("body"))
         return bodynode
 
     def addsourceunit(self, source, filename="NoName", createifmissing=False):
         """adds the given trans-unit to the last used body node if the filename has changed it uses the slow method instead (will create the nodes required if asked). Returns success"""
         if self._filename != filename:
             if not self.switchfile(filename, createifmissing):
-              return None
+                return None
         unit = super(xlifffile, self).addsourceunit(source)
         self._messagenum += 1
         unit.setid("%d" % self._messagenum)
-        unit.xmlelement.setAttribute("xml:space", "preserve")
+        lisa.setXMLspace(unit.xmlelement, "preserve")
         return unit
 
     def switchfile(self, filename, createifmissing=False):
@@ -430,12 +443,12 @@ class xlifffile(lisa.LISAfile):
             if not createifmissing:
                 return False
             filenode = self.createfilenode(filename)
-            self.document.documentElement.appendChild(filenode)
+            self.document.getroot().append(filenode)
 
         self.body = self.getbodynode(filenode, createifmissing=createifmissing)
         if self.body is None:
             return False
-        self._messagenum = len(list(self.body.getElementsByTagName("trans-unit")))
+        self._messagenum = len(self.body.findall(".//%s" % self.namespaced("trans-unit")))
         #TODO: was 0 based before - consider
     #    messagenum = len(self.units)
         #TODO: we want to number them consecutively inside a body/file tag
@@ -447,11 +460,10 @@ class xlifffile(lisa.LISAfile):
         """adds a group tag into the specified file"""
         if self._filename != filename:
             if not self.switchfile(filename, createifmissing):
-              return None
-        group = self.document.createElement("group")
+                return None
+        group = etree.SubElement(self.body, self.namespaced("group"))
         if restype:
-            group.setAttribute("restype", restype)
-        self.body.appendChild(group)
+            group.set("restype", restype)
         return group
         
     def __str__(self):
@@ -463,7 +475,8 @@ class xlifffile(lisa.LISAfile):
         xliff = super(xlifffile, cls).parsestring(storestring)
         if xliff.units:
             header = xliff.units[0]
-            if ("gettext-domain-header" in header.getrestype() or xliff.getdatatype() == "po") \
+            if ("gettext-domain-header" in (header.getrestype() or "") \
+                    or xliff.getdatatype() == "po") \
                     and cls.__name__.lower() != "poxlifffile":
                 import poxliff
                 xliff = poxliff.PoXliffFile.parsestring(storestring)
