@@ -19,12 +19,16 @@
 # along with translate; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-"""script that restructures po files from poconflicts into the original directory tree"""
+"""Restructure Gettxt PO files produced by poconflicts into the original 
+directory tree for merging using pomerge
+
+See: http://translate.sourceforge.net/wiki/toolkit/porestructure for examples and
+usage instructions
+"""
 
 import sys, os
 from translate.storage import po
 from translate.misc import optrecurse
-from translate.misc import optparse
 
 class SplitOptionParser(optrecurse.RecursiveOptionParser):
     """a specialized Option Parser for posplit"""
@@ -36,12 +40,12 @@ class SplitOptionParser(optrecurse.RecursiveOptionParser):
         return (options, args)
  
     def set_usage(self, usage=None):
-      """sets the usage string - if usage not given, uses getusagestring for each option"""
-      if usage is None:
-          self.usage = "%prog " + " ".join([self.getusagestring(option) for option in self.option_list]) + \
-          "\n  input directory is searched for PO files with (poconflicts) comments, all entries are written to files in a directory structure for pomerge"
-      else:
-          super(SplitOptionParser, self).set_usage(usage)
+        """sets the usage string - if usage not given, uses getusagestring for each option"""
+        if usage is None:
+            self.usage = "%prog " + " ".join([self.getusagestring(option) for option in self.option_list]) + \
+            "\n  input directory is searched for PO files with (poconflicts) comments, all entries are written to files in a directory structure for pomerge"
+        else:
+            super(SplitOptionParser, self).set_usage(usage)
 
     def recursiveprocess(self, options):
         """recurse through directories and process files"""
@@ -51,7 +55,7 @@ class SplitOptionParser(optrecurse.RecursiveOptionParser):
                 #TODO: maybe we should only allow it to be created, otherwise we mess up an existing tree...
                 os.mkdir(options.output)
             except:
-                self.error(optparse.OptionValueError("Output directory does not exist, attempt to create failed"))
+                self.error(optrecurse.optparse.OptionValueError("Output directory does not exist, attempt to create failed"))
         if self.isrecursive(options.input, 'input') and getattr(options, "allowrecursiveinput", True):
             if isinstance(options.input, list):
                 inputfiles = self.recurseinputfilelist(options)
