@@ -1,17 +1,16 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from translate.tools import pocount
 from translate.storage import po
-from translate.misc import wStringIO
+from translate.storage import statsdb
 
 class TestPOCount:
     def count(self, source, expectedsource, target=None, expectedtarget=None):
         """simple helper to check the respective word counts"""
         poelement = po.pounit(source)
         if target is not None:
-          poelement.settarget(target)
-        wordssource, wordstarget = pocount.wordsinpoel(poelement)
+          poelement.target = target
+        wordssource, wordstarget = statsdb.wordsinunit(poelement)
         print 'Source (expected=%d; actual=%d): "%s"' % (expectedsource, wordssource, source)
         assert wordssource == expectedsource
         if target is not None:
