@@ -65,9 +65,9 @@ class TestPOGrep:
                                          (poascii, queryunicode, ''),
                                          (pounicode, queryascii, ''),
                                          (pounicode, queryunicode, pounicode)]:
-          print "Source:\n%s\nSearch: %s\n" % (source, search)
-          poresult = self.pogrep(source, search)
-          assert poresult == expected
+            print "Source:\n%s\nSearch: %s\n" % (source, search)
+            poresult = self.pogrep(source, search)
+            assert poresult == expected
 
     def test_unicode_message_regex_searchstring(self):
         """check that we can grep unicode messages and use unicode regex search strings"""
@@ -79,9 +79,26 @@ class TestPOGrep:
                                          (poascii, queryunicode, ''),
                                          (pounicode, queryascii, ''),
                                          (pounicode, queryunicode, pounicode)]:
-          print "Source:\n%s\nSearch: %s\n" % (source, search)
-          poresult = self.pogrep(source, search, ["--regexp"])
-          assert poresult == expected
+            print "Source:\n%s\nSearch: %s\n" % (source, search)
+            poresult = self.pogrep(source, search, ["--regexp"])
+            assert poresult == expected
+
+    def test_unicode_normalise(self):
+        """check that we normlise unicode strings before comparing"""
+        source_template = u'# comment\n#: test.c\nmsgid "test"\nmsgstr "t%sst"\n'
+        # é, e + '
+        # Ḽ, L + ^
+        # Ṏ
+        groups = [(u"\u00e9", u"\u0065\u0301"), \
+                  (u"\u1e3c", u"\u004c\u032d"), \
+                  (u"\u1e4e", u"\u004f\u0303\u0308", u"\u00d5\u0308")]
+        for letters in groups:
+            for source_letter in letters:
+                source = source_template % source_letter
+                for search_letter in letters:
+                    print search_letter.encode('utf-8')
+                    poresult = self.pogrep(source, search_letter)
+                    assert poresult == source.encode('utf-8')
 
 class TestXLiffGrep:
     xliff_skeleton = '''<?xml version="1.0" ?>
