@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 from translate.tools import pomerge
+from translate.storage import factory
 from translate.storage import po
 from translate.storage import xliff 
 from translate.misc import wStringIO
@@ -16,12 +17,12 @@ class TestPOMerge:
   </file>
 </xliff>'''
 
-    def mergepo(self, templatesource, inputsource):
+    def mergestore(self, templatesource, inputsource):
         """merges the sources of the given files and returns a new pofile object"""
         templatefile = wStringIO.StringIO(templatesource)
         inputfile = wStringIO.StringIO(inputsource)
         outputfile = wStringIO.StringIO()
-        assert pomerge.mergepo(inputfile, outputfile, templatefile)
+        assert pomerge.mergestore(inputfile, outputfile, templatefile)
         outputpostring = outputfile.getvalue()
         outputpofile = po.pofile(outputpostring)
         return outputpofile
@@ -31,7 +32,7 @@ class TestPOMerge:
         templatefile = wStringIO.StringIO(templatesource)
         inputfile = wStringIO.StringIO(inputsource)
         outputfile = wStringIO.StringIO()
-        assert pomerge.mergexliff(inputfile, outputfile, templatefile)
+        assert pomerge.mergestore(inputfile, outputfile, templatefile)
         outputxliffstring = outputfile.getvalue()
         print "Generated XML:"
         print outputxliffstring
@@ -54,29 +55,38 @@ class TestPOMerge:
         """checks that a simple po entry merges OK"""
         templatepo = '''#: simple.test\nmsgid "Simple String"\nmsgstr ""\n'''
         inputpo = '''#: simple.test\nmsgid "Simple String"\nmsgstr "Dimpled Ring"\n'''
-        pofile = self.mergepo(templatepo, inputpo)
+        pofile = self.mergestore(templatepo, inputpo)
         pounit = self.singleunit(pofile)
-        assert po.unquotefrompo(pounit.msgid) == "Simple String"
-        assert po.unquotefrompo(pounit.msgstr) == "Dimpled Ring"
+        assert pounit.source == "Simple String"
+        assert pounit.target == "Dimpled Ring"
 
     def test_replacemerge(self):
         """checks that a simple po entry merges OK"""
         templatepo = '''#: simple.test\nmsgid "Simple String"\nmsgstr "Dimpled Ring"\n'''
         inputpo = '''#: simple.test\nmsgid "Simple String"\nmsgstr "Dimpled King"\n'''
-        pofile = self.mergepo(templatepo, inputpo)
+        pofile = self.mergestore(templatepo, inputpo)
         pounit = self.singleunit(pofile)
-        assert po.unquotefrompo(pounit.msgid) == "Simple String"
-        assert po.unquotefrompo(pounit.msgstr) == "Dimpled King"
+        assert pounit.source == "Simple String"
+        assert pounit.target == "Dimpled King"
+
+    def test_merging_locations(self):
+        """check that locations on seperate lines are output in Gettext form of all on one line"""
+        templatepo = '''#: location.c:1\n#: location.c:2\nmsgid "Simple String"\nmsgstr ""\n'''
+        inputpo = '''#: location.c:1\n#: location.c:2\nmsgid "Simple String"\nmsgstr "Dimpled Ring"\n'''
+        expectedpo = '''#: location.c:1%slocation.c:2\nmsgid "Simple String"\nmsgstr "Dimpled Ring"\n''' % po.lsep
+        pofile = self.mergestore(templatepo, inputpo)
+        print pofile
+        assert str(pofile) == expectedpo
 
     def test_reflowed_source_comments(self):
         """ensure that we don't duplicate source comments (locations) if they have been reflowed"""
         templatepo = '''#: newMenu.label\n#: newMenu.accesskey\nmsgid "&New"\nmsgstr ""\n'''
         newpo = '''#: newMenu.label newMenu.accesskey\nmsgid "&New"\nmsgstr "&Nuwe"\n'''
-        expectedpo = '''#: newMenu.label\n#: newMenu.accesskey\nmsgid "&New"\nmsgstr "&Nuwe"\n'''
-        pofile = self.mergepo(templatepo, newpo)
+        expectedpo = '''#: newMenu.label%snewMenu.accesskey\nmsgid "&New"\nmsgstr "&Nuwe"\n''' % po.lsep
+        pofile = self.mergestore(templatepo, newpo)
         pounit = self.singleunit(pofile)
         print pofile
-        assert pofile.getoutput() == expectedpo
+        assert str(pofile) == expectedpo
 
     def test_comments_with_blank_lines(self):
         """ensure that we don't loose empty newlines in comments"""
@@ -89,34 +99,34 @@ msgstr "blabla"
 '''
         newpo = templatepo
         expectedpo =  templatepo
-        pofile = self.mergepo(templatepo, newpo)
+        pofile = self.mergestore(templatepo, newpo)
         pounit = self.singleunit(pofile)
         print pofile
-        assert pofile.getoutput() == expectedpo
+        assert str(pofile) == expectedpo
 
     def test_merge_dont_delete_unassociated_comments(self):
         """ensure that we do not delete comments in the PO file that are not assocaited with a message block"""
         templatepo = '''# Lonely comment\n\n# Translation comment\nmsgid "Bob"\nmsgstr "Toolmaker"\n'''
         mergepo = '''# Translation comment\nmsgid "Bob"\nmsgstr "Builder"\n'''
         expectedpo = '''# Lonely comment\n\n# Translation comment\nmsgid "Bob"\nmsgstr "Builder"\n'''
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
 #        pounit = self.singleunit(pofile)
         print pofile
-        assert pofile.getoutput() == expectedpo
+        assert str(pofile) == expectedpo
 
     def test_preserve_format_trailing_newlines(self):
         """Test that we can merge messages correctly that end with a newline"""
         templatepo = '''msgid "Simple string\\n"\nmsgstr ""\n'''
         mergepo = '''msgid "Simple string\\n"\nmsgstr "Dimpled ring\\n"\n'''
         expectedpo = '''msgid "Simple string\\n"\nmsgstr "Dimpled ring\\n"\n'''
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
         print "Expected:\n%s\n\nMerged:\n%s" % (expectedpo, str(pofile))
         assert str(pofile) == expectedpo
 
         templatepo = '''msgid ""\n"Simple string\\n"\nmsgstr ""\n'''
         mergepo = '''msgid ""\n"Simple string\\n"\nmsgstr ""\n"Dimpled ring\\n"\n'''
         expectedpo = '''msgid ""\n"Simple string\\n"\nmsgstr "Dimpled ring\\n"\n'''
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
         print "Expected:\n%s\n\nMerged:\n%s" % (expectedpo, str(pofile))
         assert str(pofile) == expectedpo
 
@@ -125,21 +135,21 @@ msgstr "blabla"
         templatepo = '''msgid "Target type:"\nmsgstr "Doelsoort"\n\n'''
         mergepo = '''msgid "Target type:"\nmsgstr "Doelsoort:"\n'''
         expectedpo = mergepo
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
         print "Expected:\n%s\n\nMerged:\n%s" % (expectedpo, str(pofile))
         assert str(pofile) == expectedpo
 
         templatepo = '''msgid "&Select"\nmsgstr "Kies"\n\n'''
         mergepo = '''msgid "&Select"\nmsgstr "&Kies"\n'''
         expectedpo = mergepo
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
         print "Expected:\n%s\n\nMerged:\n%s" % (expectedpo, str(pofile))
         assert str(pofile) == expectedpo
 
         templatepo = '''msgid "en-us, en"\nmsgstr "en-us, en"\n'''
         mergepo = '''msgid "en-us, en"\nmsgstr "af-za, af, en-za, en-gb, en-us, en"\n'''
         expectedpo = mergepo
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
         print "Expected:\n%s\n\nMerged:\n%s" % (expectedpo, str(pofile))
         assert str(pofile) == expectedpo
 
@@ -148,14 +158,14 @@ msgstr "blabla"
         templatepo = '''msgid "First"\nmsgstr ""\n\nmsgid "Second"\nmsgstr ""\n'''
         mergepo = '''msgid "First"\nmsgstr "Eerste"\n\nmsgid "Second"\nmsgstr "Tweede"\n'''
         expectedpo = '''msgid "First"\nmsgstr "Eerste"\n\nmsgid "Second"\nmsgstr "Tweede"\n'''
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
         print "Expected:\n%s\n\nMerged:\n%s" % (expectedpo, str(pofile))
         assert str(pofile) == expectedpo
 
         templatepo = '''msgid "First"\nmsgstr ""\n\nmsgid "Second"\nmsgstr ""\n\n'''
         mergepo = '''msgid "First"\nmsgstr "Eerste"\n\nmsgid "Second"\nmsgstr "Tweede"\n'''
         expectedpo = '''msgid "First"\nmsgstr "Eerste"\n\nmsgid "Second"\nmsgstr "Tweede"\n'''
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
         print "Expected:\n%s\n\nMerged:\n%s" % (expectedpo, str(pofile))
         assert str(pofile) == expectedpo
 
@@ -168,7 +178,7 @@ msgstr "blabla"
         expectedpo = r'''imsgid "First\tSecond"
 msgstr "Eerste\tTweede"
 '''
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
         print "Expected:\n%s\n\nMerged:\n%s" % (expectedpo, str(pofile))
         assert str(pofile) == expectedpo
 
@@ -177,7 +187,7 @@ msgstr "Eerste\tTweede"
         templatepo = '''#: filename\nmsgid "Desktop Background.bmp"\nmsgstr "Desktop Background.bmp"\n\n'''
         mergepo = '''# (pofilter) unchanged: please translate\n#: filename\nmsgid "Desktop Background.bmp"\nmsgstr "Desktop Background.bmp"\n'''
         expectedpo = mergepo
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
         print "Expected:\n%s\n\nMerged:\n%s" % (expectedpo, str(pofile))
         assert str(pofile) == expectedpo
 
@@ -186,21 +196,21 @@ msgstr "Eerste\tTweede"
         templatepo = '''# User comment\n# (pofilter) Translate Toolkit comment\n#. Automatic comment\n#: location_comment.c:110\nmsgid "File"\nmsgstr "File"\n\n'''
         mergepo =  '''# User comment\r\n# (pofilter) Translate Toolkit comment\r\n#. Automatic comment\r\n#: location_comment.c:110\r\nmsgid "File"\r\nmsgstr "Ifayile"\r\n\r\n'''
         expectedpo = '''# User comment\n# (pofilter) Translate Toolkit comment\n#. Automatic comment\n#: location_comment.c:110\nmsgid "File"\nmsgstr "Ifayile"\n'''
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
         assert str(pofile) == expectedpo
 
         # Unassociated comment
         templatepo = '''# Lonely comment\n\n#: location_comment.c:110\nmsgid "Bob"\nmsgstr "Toolmaker"\n'''
         mergepo = '''# Lonely comment\r\n\r\n#: location_comment.c:110\r\nmsgid "Bob"\r\nmsgstr "Builder"\r\n\r\n'''
         expectedpo = '''# Lonely comment\n\n#: location_comment.c:110\nmsgid "Bob"\nmsgstr "Builder"\n'''
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
         assert str(pofile) == expectedpo
 
         # New comment
         templatepo = '''#: location_comment.c:110\nmsgid "File"\nmsgstr "File"\n\n'''
         mergepo =  '''# User comment\r\n# (pofilter) Translate Toolkit comment\r\n#: location_comment.c:110\r\nmsgid "File"\r\nmsgstr "Ifayile"\r\n\r\n'''
         expectedpo = '''# User comment\n# (pofilter) Translate Toolkit comment\n#: location_comment.c:110\nmsgid "File"\nmsgstr "Ifayile"\n'''
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
         assert str(pofile) == expectedpo
 
     def test_xliff_into_xliff(self):
@@ -216,7 +226,7 @@ msgstr "Eerste\tTweede"
         assert len(xlifffile.units) == 1
         unit = xlifffile.units[0]
         assert unit.source == "red"
-        assert unit.target== "rooi"
+        assert unit.target == "rooi"
 
     def test_po_into_xliff(self):
         templatexliff = self.xliffskeleton % '''<trans-unit>
@@ -228,7 +238,7 @@ msgstr "Eerste\tTweede"
         assert len(xlifffile.units) == 1
         unit = xlifffile.units[0]
         assert unit.source == "red"
-        assert unit.target== "rooi"
+        assert unit.target == "rooi"
         
     def test_xliff_into_po(self):
         templatepo = '# my comment\nmsgid "red"\nmsgstr ""'
@@ -237,7 +247,7 @@ msgstr "Eerste\tTweede"
         <target>rooi</target>
 </trans-unit>'''
         expectedpo = '# my comment\nmsgid "red"\nmsgstr "rooi"\n'
-        pofile = self.mergepo(templatepo, mergexliff)
+        pofile = self.mergestore(templatepo, mergexliff)
         assert str(pofile) == expectedpo
 
     def test_merging_dont_merge_kde_comments_found_in_translation(self):
@@ -246,7 +256,7 @@ msgstr "Eerste\tTweede"
         templatepo = '''msgid "_: KDE comment\\n"\n"File"\nmsgstr "File"\n\n'''
         mergepo = '''msgid "_: KDE comment\\n"\n"File"\nmsgstr "_: KDE comment\\n"\n"Ifayile"\n\n'''
         expectedpo = '''msgid ""\n"_: KDE comment\\n"\n"File"\nmsgstr "Ifayile"\n'''
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
         print "Expected:\n%s\n\nMerged:\n%s" % (expectedpo, str(pofile))
         assert str(pofile) == expectedpo
         
@@ -259,7 +269,7 @@ msgstr "Eerste\tTweede"
         templatepo = '''msgid "_: KDE "\n"comment\\n"\n"File"\nmsgstr "File"\n\n'''
         mergepo = '''msgid "_: KDE "\n"comment\\n"\n"File"\nmsgstr "_: KDE "\n"comment\\n"\n"Ifayile"\n\n'''
         expectedpo = '''msgid ""\n"_: KDE comment\\n"\n"File"\nmsgstr "Ifayile"\n'''
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
         print "Expected:\n%s\n\nMerged:\n%s" % (expectedpo, str(pofile))
         assert str(pofile) == expectedpo
 
@@ -277,22 +287,20 @@ msgid "_: sendMessageCheckWindowTitle sendMessageCheckWindowTitle.accesskey\n"
 "Send Message"
 msgstr ""
 '''
-        mergepo = r'''#: sendMsgTitle
-#: sendMsgTitle.accesskey
+        mergepo = r'''#: sendMsgTitle%ssendMsgTitle.accesskey
 msgid ""
 "_: sendMsgTitle sendMsgTitle.accesskey\n"
 "Send Message"
 msgstr "Stuur"
 
-#: sendMessageCheckWindowTitle
-#: sendMessageCheckWindowTitle.accesskey
+#: sendMessageCheckWindowTitle%ssendMessageCheckWindowTitle.accesskey
 msgid ""
 "_: sendMessageCheckWindowTitle sendMessageCheckWindowTitle.accesskey\n"
 "Send Message"
 msgstr "Stuur"
-'''
+''' % (po.lsep, po.lsep)
         expectedpo = mergepo
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
         print "Expected:\n%s\n---\nMerged:\n%s\n---" % (expectedpo, str(pofile))
         assert str(pofile) == expectedpo
 
@@ -354,6 +362,6 @@ msgstr ""
 msgid "Simple String"
 msgstr "Dimpled Ring"
 '''
-        pofile = self.mergepo(templatepo, mergepo)
+        pofile = self.mergestore(templatepo, mergepo)
         print "Expected:\n%s\n---\nMerged:\n%s\n---" % (expectedpo, str(pofile))
         assert str(pofile) == expectedpo
